@@ -1,9 +1,23 @@
-// Bayes update scheme
-//
-// started November 2000
-// Peter Beerli Seattle 2000
-// $Id: bayes->c,v 1.4 2001/07/25 19:27:23 beerli Exp $
-//
+/*------------------------------------------------------
+Maximum likelihood estimation
+of migration rate  and effectice population size
+using a Metropolis-Hastings Monte Carlo algorithm
+-------------------------------------------------------
+ Bayesian   R O U T I N E S
+ 
+ Peter Beerli 2001, Seattle
+ beerli@gs.washington.edu
+ 
+ Copyright 2001-2002 Peter Beerli
+ 
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+ 
+ $Id: bayes->c,v 1.4 2001/07/25 19:27:23 beerli Exp $
+*/
+
 #include "bayes.h"
 #include "random.h"
 #ifdef BAYESUPDATE
@@ -176,9 +190,9 @@ void bayes_fill(world_fmt *world, option_fmt *options)
       world->bayes->minparam[i] = SMALLEST_MIGRATION;
       world->bayes->maxparam[i] = BIGGEST_MIGRATION;
     }
-  //	memcpy(world->bayes->delta, options->bayes->delta,sizeof(double)*world->numpop2);
-  //	memcpy(world->bayes->minparam, options->bayes->minparam,sizeof(double)*world->numpop2);
-  //	memcpy(world->bayes->maxparam, options->bayes->maxparam,sizeof(double)*world->numpop2);
+  // memcpy(world->bayes->delta, options->bayes->delta,sizeof(double)*world->numpop2);
+  // memcpy(world->bayes->minparam, options->bayes->minparam,sizeof(double)*world->numpop2);
+  // memcpy(world->bayes->maxparam, options->bayes->maxparam,sizeof(double)*world->numpop2);
 }
 
 void bayes_free(world_fmt *world)
@@ -197,15 +211,35 @@ void bayes_stat(world_fmt *world, long size)
 {
   long i, j;
   bayes_fmt *bayes = world->bayes;
+  double temp;
+  double **rawstat;
+  rawstat = calloc(world->numpop2+1,sizeof(double *));
+  rawstat[0] = calloc((world->numpop2+1) * bayes->numparams,sizeof(double));
+
+  for(j=1; j< world->numpop2+1; j++)
+    rawstat[i] = rawstat[0] + j * (world>numpop2+1);
 
   for(i=0; i< bayes->numparams; i++)
     {
       for(j=0; j< world->numpop2+1; j++)
         {
           fprintf(world->bayesfile, "%f ", bayes->params[i][j]);
+          averages[j] += (temp=bayes->params[i][j]);
+          std[j] += temp * temp;
+          rawstat[j][i] = temp;
         }
       fprintf(world->bayesfile, "\n");
     }
+  for(j=0; j< world->numpop2+1; j++)
+    {
+      qsort(rawstat[j],bayes->numparams,sizeof(double),numcmp);
+      fprintf(world->outfile,"Parameter %li:",j+1);
+      fprintf(world->outfile,"{2.5\% percentile, median, 97.5\% percentile} = {%f , %f , %f}\n",
+              rawstat[j][(long)(bayes->numparams * 0.025)],     rawstat[j][(long)(bayes->numparams * 0.5)],
+              rawstat[j][(long)(bayes->numparams * 0.975)]);
+    }
+  free(rawstat[0]);
+  free(rawstat);
   //average:
   //mode:
   //credibility interval:
