@@ -16,7 +16,12 @@
  beerli@genetics.washington.edu
  
  
-Copyright 2001 Peter Beerli and Joseph Felsenstein
+    Copyright 2001 Peter Beerli and Joseph Felsenstein
+ 
+    This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
  
 $Id: combroyden2.c,v 1.74 2001/09/07 23:56:13 beerli Exp $
  
@@ -209,9 +214,7 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
   if (myID == MASTER)
     {
       // just use last world->param0 this might need improvement
-      // and perahsp even gathering of param0 from slave nodes
-      //      for (i = 0; i < world->numpop2; ++i)
-      //	world->param0[i] = 1.;
+      // and perhaps even gathering of param0 from slave nodes
     }
 #else
   if (kind == MULTILOCUS || repkind != SINGLECHAIN)
@@ -222,6 +225,12 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
 #endif
 
   memcpy (param, world->param0, sizeof (double) * nr->numpop2);
+#ifdef LONGSUM
+
+  memcpy (param+nr->numpop2+
+          ((world->options->gamma && kind==MULTILOCUS) ? 1 : 0) , world->flucrates, sizeof (double) * nr->numpop*3);
+#endif
+
   if (strpbrk (world->options->custm2, "0c"))
     {
       if (kind == SINGLELOCUS
@@ -255,6 +264,11 @@ estimateParameter (long rep, long G, world_fmt * world, option_fmt * options,
           (!world->options->replicate && repkind == SINGLECHAIN))
         create_loci_plot (world, world->plane[world->loci], nr, world->loci);
     }
+#ifdef LONGSUM
+  memcpy (world->flucrates, param+nr->numpop2+
+          ((world->options->gamma && kind==MULTILOCUS) ? 1 : 0), sizeof (double) * nr->numpop*3);
+#endif
+
   world->trials = trials;
   world->normd = nr->normd;
   free (param);
@@ -303,7 +317,7 @@ calc_loci_like (helper_fmt * helper, double *param, double *lparam)
 #endif /* NOT MPI */
 
     }
-  else				/* ->singlelocus */
+  else    /* ->singlelocus */
     logres = calc_locus_like (nr, param, lparam, nr->world->locus);
   nr->llike = logres;
   return nr->llike;
@@ -317,6 +331,7 @@ slow_net_calc_loci_like (helper_fmt * helper, double *param, double *lparam)
   long locus;
   nr_fmt *nr = helper->nr;
   world_fmt *world = helper->nr->world;
+  double *mu_rates = world->options->mu_rates;
   double logres = 0;
   if (helper->multilocus)
     {
@@ -327,7 +342,7 @@ slow_net_calc_loci_like (helper_fmt * helper, double *param, double *lparam)
               if (nr->skiploci[locus])
                 continue;
               nr->locilikes[locus] =
-                calc_locus_like (nr, param, lparam, locus);
+                calc_locus_like (nr, param, lparam, locus) + mu_rates[locus];
               logres += nr->locilikes[locus];
             }
         }
@@ -336,7 +351,7 @@ slow_net_calc_loci_like (helper_fmt * helper, double *param, double *lparam)
           logres = gamma_loci_like (helper, param, lparam, helper->weight);
         }
     }
-  else				/* ->singlelocus */
+  else    /* ->singlelocus */
     logres = calc_locus_like (nr, param, lparam, nr->world->locus);
   nr->llike = logres;
   return nr->llike;
@@ -396,7 +411,7 @@ combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv)
           mpi_gradient_master (nr, nr->world, nr->world->who);
           memcpy (gxv, nr->d, sizeof (double) * nr->partsize);
         }
-      else			//SLAVE
+      else   //SLAVE
         {
           error ("not allowed to execute mpi_gradient_worker()\n");
         }
@@ -420,7 +435,7 @@ combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv)
           //else
           gamma_loci_derivative (helper);
           memcpy (gxv, nr->d, sizeof (double) * nr->partsize);
-          /*	  save_a = helper->xv[nr->partsize-1];
+          /*   save_a = helper->xv[nr->partsize-1];
           la= save_a - save_a/100.;
           helper->xv[nr->partsize-1]=la;
           helper->expxv[nr->partsize-1]=exp(la);
@@ -434,7 +449,7 @@ combine_gradient (nr_fmt * nr, helper_fmt * helper, double *gxv)
           nr->d[nr->partsize-1] = (fla - fha)/(la-ha);
           memcpy (gxv, nr->d, sizeof (double) * nr->partsize);*/
           //#else
-          //	  dt (gxv, helper);
+          //   dt (gxv, helper);
           //endif  /*LAGUERRE*/
         }
 #endif /*MPI*/
@@ -498,7 +513,14 @@ simple_loci_derivatives (double *d, nr_fmt * nr, timearchive_fmt ** tyme,
                          long locus)
 {
   long g;
-  gradient (d, nr, locus);
+#ifndef LONGSUM
+
+  gradient(d, nr, locus);
+#else /*LONGSUM*/
+
+  gradient_longsum (d, nr, locus);
+#endif /*LONGSUM*/
+
   for (g = 0; g < nr->partsize - nr->profilenum; g++)
     d[g] /= nr->PGC[locus];
 }
@@ -529,15 +551,15 @@ set_gamma_param (double *param, double *oparam,
 void
 copy_and_clear_d (nr_fmt * nr)
 {
-  memcpy (nr->od, nr->d, sizeof (double) * nr->numpop2);
-  memset (nr->d, 0, sizeof (double) * nr->numpop2);
+  memcpy (nr->od, nr->d, sizeof (double) * nr->partsize);
+  memset (nr->d, 0, sizeof (double) * nr->partsize);
 }
 
 void
 add_back_d (nr_fmt * nr)
 {
   long pop;
-  for (pop = 0; pop < nr->numpop2; pop++)
+  for (pop = 0; pop < nr->partsize; pop++)
     {
       nr->d[pop] += nr->od[pop];
     }
@@ -705,17 +727,17 @@ void copy_nr (nr_fmt * in, nr_fmt * out)
   else
     {
       if (!in->world->options->gamma && in->world->locus >= in->world->loci)
-	{
-	  out->categs = 0;
-	  out->rate = NULL;
-	  out->partsize = in->world->numpop2;
-	}
+ {
+   out->categs = 0;
+   out->rate = NULL;
+   out->partsize = in->world->numpop2;
+ }
       else
-	{
-	  out->categs = 0;
-	  out->rate = NULL;
-	  out->partsize = in->world->numpop2;
-	}
+ {
+   out->categs = 0;
+   out->rate = NULL;
+   out->partsize = in->world->numpop2;
+ }
     }
   out->atl = in->atl;
   out->parts = (double *) calloc (out->partsize, sizeof (double));
@@ -834,7 +856,7 @@ line_search (double *dv, double *gxv,
   b = 1.0;
 
   la = -oldL;
-  lb = -oldL;			//(*fpsi) (b, &helper, tempparam, templparam);
+  lb = -oldL;   //(*fpsi) (b, &helper, tempparam, templparam);
   //  ll = (*fpsi) (m, &helper, tempparam, templparam);
   //if(ll > la)
   //  c =  -1.;
@@ -944,9 +966,9 @@ psil (double (*fpsi) (double lamda, helper_fmt * helper), double a, double b,
   if (a == 0.0 && b == 0)
     {
       for (i = 0; i < nn; i++)
-	{
-	  value += dv[i];  // gxv[i]  ;
-	}	
+ {
+   value += dv[i];  // gxv[i]  ;
+ } 
       *val1 = -oldL;
       *val2 = -oldL;
       return value;
@@ -954,19 +976,19 @@ psil (double (*fpsi) (double lamda, helper_fmt * helper), double a, double b,
   else
     {
       if (a == 0)
-	value = (((*val2) = (*fpsi) (b, helper)) - ((*val1) = -oldL)) / b;
+ value = (((*val2) = (*fpsi) (b, helper)) - ((*val1) = -oldL)) / b;
       else
-	{
-	  if (b == 0)
-	    value =
-	      (((*val2) = -oldL) - ((*val1) = (*fpsi) (a, helper))) / (-a);
-	  else
-	    value =
-	      (((*val2) = (*fpsi) (b, helper)) - ((*val1) =
-						  (*fpsi) (a,
-							   helper))) / (b -
-									a);
-	}
+ {
+   if (b == 0)
+     value =
+       (((*val2) = -oldL) - ((*val1) = (*fpsi) (a, helper))) / (-a);
+   else
+     value =
+       (((*val2) = (*fpsi) (b, helper)) - ((*val1) =
+        (*fpsi) (a,
+          helper))) / (b -
+         a);
+ }
       return value;
     }
 }
@@ -1209,15 +1231,15 @@ setup_parameter0_standard (world_fmt * world, nr_fmt * nr, long repkind,
                                  &world->atl[r][locus], locus);
                   interpolate_like (nr, locus);
                 }
-//              else
- //               {
-                  for (r = repstart; r < repstop; r++)
-                    create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
-//                }
+              //              else
+              //               {
+              for (r = repstart; r < repstop; r++)
+                create_multiapg0 (nr->apg0[r][locus], nr, r, locus);
+              //                }
             }
         }
     }
-  else				//single locus
+  else    //single locus
     {
       if (repkind == SINGLECHAIN)
         {
@@ -1318,8 +1340,8 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   double normd = 1000000;
   double normd20 = DBL_MAX;
   worldoption_fmt *wopt = world->options;
-  long nnn = nr->partsize;	// keeps track of profile or standard
-  long nn;			// keeps track of the full parameter array
+  long nnn = nr->partsize; // keeps track of profile or standard
+  long nn;   // keeps track of the full parameter array
   double **hess;
   double *delta;
   double *gama;
@@ -1330,8 +1352,8 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   double *xv;
   double *expxv;
   double *temp;
-  double *tempparam;		//just pointer into temp
-  double *templparam;		//just pointer into temp
+  double *tempparam;  //just pointer into temp
+  double *templparam;  //just pointer into temp
   helper_fmt helper;
 
   //  long reset_z = 0;
@@ -1363,6 +1385,11 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   prepare_broyden (analystype, world, &helper.multilocus);
   nnn = multilocus_gamma_adjust (helper.multilocus, helper.boolgamma,
                                  world, repstart, repstop);
+#ifdef LONGSUM
+
+  nnn=nr->partsize;
+#endif
+
   nn = nnn;
   //if(helper.boolgamma)
   //{
@@ -1376,9 +1403,9 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
   helper.dv = dv;
   calc_loci_param (nr, xv, xv0, gxv, 0., nnn);
   set_expparam (expxv, xv, nn);
-//SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
-//             world->loci, analystype, helper.multilocus);
-//   fprintf(stdout,"analystype is %li\n",analystype);
+  //SETUPPARAM0 (world, nr, world->repkind, repstart, repstop,
+  //             world->loci, analystype, helper.multilocus);
+  //   fprintf(stdout,"analystype is %li\n",analystype);
 
   fill_helper (&helper, expxv, xv, world, nr);
   oldL = CALCLIKE (&helper, expxv, xv);
@@ -1400,7 +1427,7 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
       if (helper.boolgamma)
         lamda = line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
       else
-        lamda =	    line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
+        lamda =     line_search (dv, gxv, psilo, &helper, oldL, tempparam, templparam);
       helper.lamda = lamda;
       while ((newL <= oldL || isnan (newL) || newL <= -DBL_MAX) &&
              fabs (lamda) > 10. * DBL_EPSILON)
@@ -1416,8 +1443,8 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
 
       if (nr->world->locus >= nr->world->loci && nr->world->options->gamma)
         {
-          //	   initgammacat (nr->categs, expxv[nr->numpop2], expxv[0],
-          //				nr->rate, nr->probcat);
+          //    initgammacat (nr->categs, expxv[nr->numpop2], expxv[0],
+          //    nr->rate, nr->probcat);
           if (fabs (oldL - newL) < 1e-9)
             lamda = 0.;
         }
@@ -1428,7 +1455,7 @@ maximize (double *param, world_fmt * world, nr_fmt * nr, long analystype,
                         world->options->logfile);
       stop = guard_broyden (newL, oldL, trials, normd, &normd20);
       if (normd < EPSILON || stop)
-        break;			// stopping criteria
+        break;   // stopping criteria
       else if (oldL >= newL)
         lamda = 0;
       else
