@@ -16,6 +16,11 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+ 
 $Id: data.c,v 1.37 2001/09/07 23:56:13 beerli Exp $
  
 -------------------------------------------------------*/
@@ -32,6 +37,7 @@ extern long number_genomes (char type);
 void create_data (data_fmt ** data);
 void get_data (FILE * infile, data_fmt * data, option_fmt * options);
 void print_data (world_fmt * world, option_fmt * options, data_fmt * data);
+long find_missing(data_fmt *data, long pop, long locus);
 void print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
                          data_fmt * data);
 void free_datapart (data_fmt * data, option_fmt * options, long locus);
@@ -41,7 +47,7 @@ void read_header (FILE * infile, data_fmt * data, option_fmt * options);
 void read_sites (data_fmt * data);
 void init_data_structure2 (data_fmt ** data, option_fmt * options, long pop);
 void init_data_structure3 (data_fmt * data);
-void read_popheader (FILE * infile, data_fmt * data, long pop);
+void read_popheader (FILE * infile, data_fmt * data, long pop, long genomes);
 void read_indname (FILE * file, data_fmt * data, long pop, long ind,
                    long nmlength);
 void read_popdata (FILE * file, data_fmt * data, long pop,
@@ -102,8 +108,10 @@ void
 get_data (FILE * infile, data_fmt * data, option_fmt * options)
 {
   long pop;
+	long genomes=1;
   data->hasghost = FALSE;
   read_header (infile, data, options);
+  genomes =  number_genomes (options->datatype);
   init_data_structure1 (&data, options);
   switch (options->datatype)
     {
@@ -129,7 +137,7 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
     fprintf (options->logfile, "\n\n");
   for (pop = 0; pop < data->numpop; pop++)
     {
-      read_popheader (data->infile, data, pop);
+      read_popheader (data->infile, data, pop, genomes);
       if (options->progress)
         fprintf (stdout, "Reading %s ...\n", data->popnames[pop]);
       if (options->writelog)
@@ -146,14 +154,21 @@ get_data (FILE * infile, data_fmt * data, option_fmt * options)
   if (options->progress)
     fprintf (stdout, "\n\n");
   init_data_structure3 (data);
-  /* replace this, if loci can have different number of ind */
+#ifndef NEWSTYLE
+    /* sets all data->numind to the numind[0] */
   set_numind (data);
+#endif
+
   switch (options->datatype)
     {
     case 'a':
       create_alleles (data);
       break;
     case 'b':
+		create_alleles (data);
+		for (pop = 0; pop < data->loci; pop++)
+			data->maxalleles[pop] = XBROWN_SIZE;
+			break;
     case 'm':
       create_alleles (data);
       for (pop = 0; pop < data->loci; pop++)
@@ -178,12 +193,15 @@ init_data_structure1 (data_fmt ** data, option_fmt * options)
       (*data)->indnames =
         (char ***) malloc (sizeof (char **) * (*data)->numpop);
       (*data)->numind = (long **) malloc (sizeof (long *) * (*data)->numpop);
+      (*data)->numalleles = (long **) malloc (sizeof (long *) * (*data)->numpop);
       for (pop = 0; pop < (*data)->numpop; pop++)
         {
           (*data)->popnames[pop] =
             (char *) calloc (1, sizeof (char) * LINESIZE);
           (*data)->numind[pop] =
-            (long *) malloc (sizeof (long) * (*data)->loci);
+			  (long *) malloc (sizeof (long) * (*data)->loci);
+          (*data)->numalleles[pop] =
+			  (long *) malloc (sizeof (long) * (*data)->loci);
         }
       (*data)->seq->sites =
         (long *) calloc (1, sizeof (long) * (*data)->loci);
@@ -199,7 +217,12 @@ void
 init_data_structure2 (data_fmt ** data, option_fmt * options, long pop)
 {
   long ind, locus;
-  long indalloc = (*data)->numind[pop][FLOC];
+  long indalloc = -1;
+  for(locus=0;locus<(*data)->loci;locus++)
+    {
+      if(indalloc < (*data)->numind[pop][locus])
+        indalloc = (*data)->numind[pop][locus];
+    }
   if (indalloc == 0)
     indalloc = 2;
   (*data)->yy[pop] = (char ****) malloc (sizeof (char ***) * indalloc);
@@ -238,10 +261,10 @@ void
 free_datapart (data_fmt * data, option_fmt * options, long locus)
 {
   long ind, pop;
-  long genomes = number_genomes (options->datatype);
+//  long genomes = number_genomes (options->datatype);
   for (pop = 0; pop < data->numpop; pop++)
     {
-      for (ind = 0; ind < data->numind[pop][locus] / genomes; ind++)
+      for (ind = 0; ind < data->numalleles[pop][locus]; ind++)
         {
           if (strchr (SEQUENCETYPES, options->datatype))
             {
@@ -269,7 +292,7 @@ init_data_structure3 (data_fmt * data)
     {
       maxi = 0;
       for (pop = 0; pop < data->numpop; pop++)
-        maxi += data->numind[pop][FLOC] * 2;
+        maxi += data->numalleles[pop][locus];
       data->allele[locus] =
         (allele_fmt *) calloc (1, sizeof (allele_fmt) * maxi);
     }
@@ -305,8 +328,8 @@ read_header (FILE * infile, data_fmt * data, option_fmt * options)
       sscanf (input, "%1s%ld%ld%[^\n]", &options->datatype, &(data->numpop),
               &(data->loci), options->title);
       break;
-    case 'g':			/* fall through if a menu change forces to analyze data
-      				   instead of using the already sampled genealogies */
+    case 'g':   /* fall through if a menu change forces to analyze data
+                       instead of using the already sampled genealogies */
       if (options->datatype == 'g')
         break;
       else
@@ -396,18 +419,76 @@ read_sites (data_fmt * data)
 }
 
 void
-read_popheader (FILE * infile, data_fmt * data, long pop)
+read_popheader (FILE * infile, data_fmt * data, long pop, long genomes)
 {
-  char input[LINESIZE], *p;
+  char input[LINESIZE], *p, *tmp;
+  long locus,lo;
+  boolean havepopname=FALSE;
   FGETS (input, sizeof (input), infile);
   if ((p = (char *) strpbrk (input, CRLF)) != NULL)
     *p = '\0';
-  sscanf (input, "%ld%[^\n]", &(data->numind[pop][FLOC]),
+#ifdef NEWSTYLE
+  // allows that sequence data can have different numbers of individuals for different loci
+  // data syntax changes: #ind1 #ind2 #IND3 .... pop_name
+  havepopname=FALSE;
+  if(data->loci>1)
+    {
+      tmp = strtok (input, " ");
+      data->numind[pop][0] = atol(tmp);
+	  data->numalleles[pop][0] = data->numind[pop][0] * genomes;
+      for(locus=1; locus< data->loci; locus++)
+        {
+          tmp = strtok(NULL," ");
+          if(isdigit(tmp[0]))
+				{
+				data->numind[pop][locus] = atol(tmp);
+			  data->numalleles[pop][locus] = data->numind[pop][locus]*genomes;
+				}						  
+          else
+            {
+              havepopname=TRUE;
+              strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
+              break;
+            }
+        }
+      if(!havepopname)
+        {
+          tmp = strtok(NULL," ");
+          strncpy(data->popnames[pop],tmp,MIN(strlen(tmp),80));
+        }
+	  // fills numind for additional locus in case the numind was not specified
+      for(lo=locus; lo< data->loci; lo++)
+		{
+        data->numind[pop][lo] = data->numind[pop][locus-1];
+		  data->numalleles[pop][lo] = data->numind[pop][lo] * genomes;
+		}
+    }
+  else
+    {
+      // only one locus so we can use old scheme [see below]
+      sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
+              data->popnames[pop]);
+	  data->numalleles[pop][0] = data->numind[pop][0]*genomes;
+    }
+#else
+  // assume all loci have the same number of individuals
+  sscanf (input, "%ld%[^\n]", &(data->numind[pop][0]),
           data->popnames[pop]);
+  data->numalleles[pop][0] = data->numind[pop][0]*genomes;
+#endif
+
   translate (data->popnames[pop], ' ', '_');
   translate (data->popnames[pop], '\t', '_');
-  if (data->numind[pop][FLOC] == 0)
-    data->hasghost = TRUE;
+//trial #ifdef NEWSTYLE
+//  for(locus=0;locus<data->loci; locus++)
+//    {
+//      if (data->numind[pop][locus] == 0)
+//        data->hasghost = FALSE ;//TRUE;
+//    }
+//#else
+//  if (data->numind[pop][0] == 0)
+//    data->hasghost = TRUE;
+//#endif
 }
 
 void
@@ -429,7 +510,7 @@ read_popdata (FILE * infile, data_fmt * data, long pop, option_fmt * options)
 {
   long ind, baseread = 0;
   long locus = 0;
-  for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+  for (ind = 0; ind < data->numind[pop][0]; ind++)
     {
       read_indname (infile, data, pop, ind, options->nmlength);
       switch (options->datatype)
@@ -604,12 +685,12 @@ read_ind_seq (FILE * infile, data_fmt * data, option_fmt * options,
         }
       data->yy[pop][ind][locus][0][j++] = charstate;
     }
-  charstate = getc (infile);	/* swallow the \n or \r */
+  charstate = getc (infile); /* swallow the \n or \r */
 #ifndef MAC
 
   if (charstate == '\r')
     {
-      charstate = getc (infile);	/* swallow the \n */
+      charstate = getc (infile); /* swallow the \n */
       if(charstate!='\n')
         ungetc((int) charstate, infile);
     }
@@ -627,8 +708,8 @@ read_distance_fromfile (FILE * dfile, long tips, long nmlength, double **m)
     {
       // assumes that the dfile is in PHYLIP format
       // and that all n x n cells are filled.
-      FGETS (input, LINESIZE, dfile);	//reads header line with
-      for (i = 0; i < tips; i++)	// of individuals
+      FGETS (input, LINESIZE, dfile); //reads header line with
+      for (i = 0; i < tips; i++) // of individuals
         {
           //reads header line with
           FGETS (input, nmlength + 1, dfile);
@@ -657,7 +738,7 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, int **uep,
     {
       // assumes that the uepfile is in PHYLIP format
       // and that all n cells are filled.
-      FGETS (input, LINESIZE, uepfile);	//reads header line with
+      FGETS (input, LINESIZE, uepfile); //reads header line with
       // of individuals and uep sites
       sscanf (input, "%li%li", &thistips, uepsites);
       if (thistips != tips)
@@ -667,7 +748,7 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, int **uep,
           for (i = 0; i < tips; i++)
             {
               uep[i] = (int *) calloc (*uepsites, sizeof (int));
-              FGETS (input, nmlength + 1, uepfile);	//reads each line
+              FGETS (input, nmlength + 1, uepfile); //reads each line
               for (j = 0; j < *uepsites; ++j)
                 fscanf (uepfile, "%i", &uep[i][j]);
               // reads the last \n from the data matrix
@@ -680,7 +761,7 @@ read_uep_fromfile (FILE * uepfile, long tips, long nmlength, int **uep,
             {
               uep[i] = (int *) calloc (*uepsites, sizeof (int));
               uep[i + tips] = (int *) calloc (*uepsites, sizeof (int));
-              FGETS (input, nmlength + 1, uepfile);	//reads each line
+              FGETS (input, nmlength + 1, uepfile); //reads each line
               for (j = 0; j < *uepsites; ++j)
                 fscanf (uepfile, "%i", &uep[i][j]);
               // finished reading first allele, no onto the second
@@ -704,7 +785,7 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
     {
       while (baseread < data->seq->sites[0])
         {
-          for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+          for (ind = 0; ind < data->numind[pop][0]; ind++)
             {
               baseread2 =
                 read_ind_seq (infile, data, options, locus, pop, ind,
@@ -716,7 +797,7 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
   for (locus = 1; locus < data->loci; locus++)
     {
       baseread = 0;
-      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      for (ind = 0; ind < data->numind[pop][locus]; ind++)
         {
           read_indname (infile, data, pop, ind, options->nmlength);
           baseread = read_ind_seq (infile, data, options, locus, pop, ind, 0);
@@ -725,7 +806,7 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
         {
           while (baseread < data->seq->sites[locus])
             {
-              for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+              for (ind = 0; ind < data->numind[pop][locus]; ind++)
                 {
                   baseread2 =
                     read_ind_seq (infile, data, options, locus, pop, ind,
@@ -737,14 +818,30 @@ finish_read_seq (FILE * infile, data_fmt * data, option_fmt * options,
     }
 }
 
+long find_missing(data_fmt *data, long pop, long locus)
+{
+  long missing = 0;
+  long ind;
+  for(ind=0; ind < data->numind[pop][locus]; ind++)
+    {
+      if(data->yy[pop][ind][locus][0][0]=='?')
+        missing++;
+      if(data->yy[pop][ind][locus][1][0]=='?')
+        missing++;
+    }
+  return missing;
+}
+
 void
 print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
                     data_fmt * data)
 {
-  long total = 0;
+  long locus;
   long pop;
+  long numind;
   char dstring[LINESIZE];
-
+  long *total;
+  total = calloc(data->loci,sizeof(long));
   fprintf (file, "Summary of data:\n");
   fprintf (file, "---------------\n");
   switch (options->datatype)
@@ -762,7 +859,7 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
       break;
     case 'n':
     case 'u':
-      strcpy (dstring, "Allelic data");
+      strcpy (dstring, "SNP data");
       break;
     default:
       strcpy (dstring, "Unknown data [ERROR]");
@@ -773,18 +870,36 @@ print_data_summary (FILE * file, world_fmt * world, option_fmt * options,
            data->loci);
 
   fprintf (file,
-           "Population                                        Individuals\n");
+           "Population                                     Locus    Gene copies\n");
   fprintf (file,
-           "-------------------------------------------------------------\n");
+           "-------------------------------------------------------------------\n");
   for (pop = 0; pop < world->numpop; pop++)
     {
-      fprintf (file, "%3li %-50.50s %6li\n", pop + 1, data->popnames[pop],
-               data->numind[pop][FLOC]);
-      total += data->numind[pop][FLOC];
+	  if (!strchr (SEQUENCETYPES, options->datatype))
+		  numind = data->numalleles[pop][0] - find_missing(data,pop,0);
+      else
+        numind = data->numind[pop][0];
+      fprintf (file, "%3li %-40.40s %5li %6li\n", pop+1, data->popnames[pop], 1L , numind);
+      total[0] += numind;
+      for(locus=1; locus< data->loci; locus++)
+        {
+          if (!strchr (SEQUENCETYPES, options->datatype))
+            numind = data->numalleles[pop][locus] - find_missing(data,pop,locus);
+          else
+            numind = data->numind[pop][locus];
+          fprintf (file,"                                             %5li %6li\n",  locus+1, numind);
+          total[locus] += numind;
+        }
     }
   fprintf (file,
-           "Total of all populations                               %6li\n\n",
-           total);
+           "Total of all populations                     %5li %6li\n",1L, total[0]);
+  for(locus=1; locus< data->loci; locus++)
+    {
+      fprintf (file,
+               "                                             %5li %6li\n",locus+1, total[locus]);
+    }
+  fprintf(file,"\n");
+  free(total);
   fflush (file);
 }
 
@@ -817,7 +932,7 @@ print_alleledata (world_fmt * world, data_fmt * data, option_fmt * options)
   for (pop = 0; pop < data->numpop; pop++)
     {
       print_header (world->outfile, pop, world, options, data);
-      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      for (ind = 0; ind < data->numind[pop][0]; ind++)
         {
           fprintf (world->outfile, "%-*.*s ", (int) options->nmlength,
                    (int) options->nmlength, data->indnames[pop][ind]);
@@ -950,7 +1065,8 @@ set_numind (data_fmt * data)
     {
       for (pop = 0; pop < data->numpop; pop++)
         {
-          data->numind[pop][locus] = data->numind[pop][FLOC];
+          data->numind[pop][locus] = data->numind[pop][0];
+          data->numalleles[pop][locus] = data->numalleles[pop][0];
         }
     }
 }
@@ -961,7 +1077,7 @@ print_seq_pop (long locus, long pop, world_fmt * world, option_fmt * options,
                data_fmt * data)
 {
   long ind;
-  for (ind = 0; ind < data->numind[pop][locus]; ind++)
+  for (ind = 0; ind < data->numalleles[pop][locus]; ind++)
     {
       print_seq_ind (locus, pop, ind, world, options, data);
     }
@@ -1033,17 +1149,17 @@ read_geofile (data_fmt * data, option_fmt * options, long numpop)
                               data->ogeo);
       for (i = 0; i < numpop; i++)
         {
-		  for (j = 0; j < numpop; j++)
-			{
-			  if(i!=j)
-				{
-				  data->geo[mm2m (i, j, numpop)] =   1. / data->ogeo[i][j];
-				  data->lgeo[mm2m (i, j, numpop)] =  data->ogeo[i][j] > 0.0 ?
-					  log (1. / data->ogeo[i][j]) : -DBL_MAX;
-				}
-			}
-		}
-	}
+          for (j = 0; j < numpop; j++)
+            {
+              if(i!=j)
+                {
+                  data->geo[mm2m (i, j, numpop)] =   1. / data->ogeo[i][j];
+                  data->lgeo[mm2m (i, j, numpop)] =  data->ogeo[i][j] > 0.0 ?
+                                                     log (1. / data->ogeo[i][j]) : -DBL_MAX;
+                }
+            }
+        }
+    }
 }
 
 #ifdef UEP
@@ -1057,7 +1173,8 @@ read_uepfile (data_fmt * data, option_fmt * options, long numpop)
     return;
 
   for (i = 0; i < numpop; ++i)
-    sumtips += data->numind[i][FLOC];
+    sumtips += data->numind[i][0];   //Assumes that UEP has the same number of individuals as
+  // locus 1 (Is this OK? most dataset with UEP will have 1 locus?????)
   data->uep = (int **) calloc (number_genomes (options->datatype) * sumtips,
                                sizeof (int *));
   read_uep_fromfile (data->uepfile, sumtips, options->nmlength, data->uep,
