@@ -15,17 +15,22 @@
   Mary Kuhner and Jon Yamato (mkkuhner@genetics.washington.edu)
  
   
-Copyright 2001 Peter Beerli and Joseph Felsenstein
+Copyright 2002 Peter Beerli and Joseph Felsenstein
  
 $Id: definitions.h,v 1.65 2001/09/07 23:56:13 beerli Exp $
  
   *----------------------------------------------------------------
   */
 #ifndef MIGRATEVERSION
-#define MIGRATEVERSION "1.5"
+#define MIGRATEVERSION "1.6.5"
+#else
+#ifdef SGI
+#undef MIGRATEVERSION
+#define MIGRATEVERSION "1.6.5"
+#endif
 #endif
 
-#define MAINTAINER "Peter Beerli <beerli@genetics.washington.edu>"
+#define MAINTAINER "Peter Beerli <beerli@gs.washington.edu>"
 /*------------------------------------------------
   Adjusting the source to the system configuration
 */
@@ -47,7 +52,7 @@ $Id: definitions.h,v 1.65 2001/09/07 23:56:13 beerli Exp $
 #define LAMARC_MALLOC
 #ifdef macintosh
 #define MAC
-#include <ansi_prefix.mac.h>	/*fixes time problems */
+#include <ansi_prefix.mac.h> /*fixes time problems */
 #else /*macintosh */
 #define DOS
 #undef HAVE_STRINGS_H
@@ -87,7 +92,7 @@ $Id: definitions.h,v 1.65 2001/09/07 23:56:13 beerli Exp $
 void vax_printf_is_broken (const char *fmt, ...);
 void vax_fprintf_is_broken (FILE * fp, const char *fmt, ...);
 void vax_tweak_fmt (char *);
-#define signed			/* signed doesn't exist in VMS */
+#define signed   /* signed doesn't exist in VMS */
 #endif /*__STDIO_LOADED*/
 
 
@@ -147,9 +152,9 @@ typedef unsigned char boolean;
 #define FIRST 0
 /* the first population is the panel for snps*/
 #define PANEL 0
-#define SEQUENCETYPES "snuf"	/*s=sequence,n=linked snp, u=unlinked snp, f=ancestral reconstruction */
+#define SEQUENCETYPES "snuf" /*s=sequence,n=linked snp, u=unlinked snp, f=ancestral reconstruction */
 #define SNPTYPES      "nu"
-#define ALLELETYPES   "amb"	/*a=infinite allele,m=stepwise, b=brownian */
+#define ALLELETYPES   "amb" /*a=infinite allele,m=stepwise, b=brownian */
 
 #define CRLF "\r\n"
 
@@ -189,15 +194,15 @@ typedef unsigned char boolean;
   */
 /* number of k int k-allele model, the number
    MUST really be bigger than the number of 
-   observed alleles, much bigger does not harm	*/
+   observed alleles, much bigger does not harm */
 #define MAXALLELES            93
 #define MAXBUFSIZE        100000
-#define LINESIZE            1024	/* setting this smaller can break */
-#define LONGLINESIZE       10000	/* setting this smaller can break */
-#define STRSIZE              255	/* setting this smaller can break */
-#define DEFAULT_NMLENGTH      10	/* length of individual names */
-#define DEFAULT_ALLELENMLENGTH 6	/* length of allele names */
-#define DEFAULT_POPNMLENGTH  100	/* length of world names */
+#define LINESIZE            1024 /* setting this smaller can break */
+#define LONGLINESIZE       10000 /* setting this smaller can break */
+#define STRSIZE              255 /* setting this smaller can break */
+#define DEFAULT_NMLENGTH      10 /* length of individual names */
+#define DEFAULT_ALLELENMLENGTH 6 /* length of allele names */
+#define DEFAULT_POPNMLENGTH  100 /* length of world names */
 #define NUMPOP 2
 #define BURNINPERIOD 10000
 #define SCALEINTERVAL 5
@@ -206,11 +211,11 @@ typedef unsigned char boolean;
    some other constants */
 /* numerical borders and epsilons*/
 #define SMALL_VALUE       10e-21
-#define EPSILON         0.000001	/* a small number */
-#define EPSILON4        0.000099	/* another small number */
-#define SMALLEPSILON       1e-15	/* a smaller number */
-#define BIGEPSILON         0.001	/* a not so small number */
-#define LONGCHAINEPSILON  10e100	/* an unreasonable big number,
+#define EPSILON         0.000001 /* a small number */
+#define EPSILON4        0.000099 /* another small number */
+#define SMALLEPSILON       1e-15 /* a smaller number */
+#define BIGEPSILON         0.001 /* a not so small number */
+#define LONGCHAINEPSILON  10e100 /* an unreasonable big number,
 
 so that the given number of
 long chains is used */
@@ -227,11 +232,11 @@ long chains is used */
 #endif
 #endif
 /* some math constants */
-#define LOGDBL_EPSILON -36.04365338911715608	/*N[Log[DBL_EPSILON] ,30] */
+#define LOGDBL_EPSILON -36.04365338911715608 /*N[Log[DBL_EPSILON] ,30] */
 #define LOG1 0.
-#define LOG2 0.693147180559945309417232121458	/*N[Log[2] ,30] */
-#define LOG2PIHALF -0.918938533204672741780329736406	/*N[Log[1/Sqrt[2 Pi]] ,30] */
-#define TWOPI 6.28318530717958647692528676656	/*N[Log[2 Pi] ,30] */
+#define LOG2 0.693147180559945309417232121458 /*N[Log[2] ,30] */
+#define LOG2PIHALF -0.918938533204672741780329736406 /*N[Log[1/Sqrt[2 Pi]] ,30] */
+#define TWOPI 6.28318530717958647692528676656 /*N[Log[2 Pi] ,30] */
 #define ROOTLENGTH         10000
 #define FIRSTCHAIN            -1
 #define FIRSTSTEP             -1
@@ -250,13 +255,13 @@ long chains is used */
 #define ATOI(a) strtol((a),(char **) NULL, 10)
 #define ATOF(a) strtod((a),(char **) NULL, 10)
 /* theta (4 Ne mu) related material */
-#define SMALLEST_THETA	   1e-10
-#define BIGGEST_THETA	     1e4
+#define SMALLEST_THETA    1e-10
+#define BIGGEST_THETA      1e4
 #define SMALLEST_MIGRATION 1e-10
 #define BIGGEST_MIGRATION   10e9
 // defines the value that is used as a minimum summary statistic for migraiton events on all trees
 // version 1.2.4 had a value of 0.00000001, it seems that values of 0.1 are too large.
-#define MINMIGSUMSTAT 0.001
+#define MINMIGSUMSTAT 0.0
 /* the migration limit is per population, should be plenty
    for moderate sample sizes */
 #define MIGRATION_LIMIT     5000
@@ -268,16 +273,16 @@ long chains is used */
 #define SAMPLETREE_GUESS       1
 #define START_ALPHA          10.0
 /* random material */
-#define AUTO                   0	/*+ use time() for seed */
-#define NOAUTO                 1	/*+ seed in parmfile   */
-#define NOAUTOSELF             2	/*+ seed in seedfile   */
+#define AUTO                   0 /*+ use time() for seed */
+#define NOAUTO                 1 /*+ seed in parmfile   */
+#define NOAUTOSELF             2 /*+ seed in seedfile   */
 /* definitions for the first theta0 values */
-#define OWN                    0	/*+ start values in parmfile */
+#define OWN                    0 /*+ start values in parmfile */
 #define WATTERSON              1 /*- start values are Watterson estimate*/
 #define EWENS                  2 /*- start values are Ewens estimate*/
-#define FST                    3	/*+ start values are FST estimate */
-#define RANDOMESTIMATE         4	/*+ start values are RANDOM estimate */
-#define PARAMGRID              5	/*+ use a range of values + replicate=yes:# */
+#define FST                    3 /*+ start values are FST estimate */
+#define RANDOMESTIMATE         4 /*+ start values are RANDOM estimate */
+#define PARAMGRID              5 /*+ use a range of values + replicate=yes:# */
 /* defines for the migration0 values */
 /* define OWN                  0   + start values in parmfile */
 /* define FST                  3   + start values are FST estimates*/
@@ -299,41 +304,41 @@ long chains is used */
 #define LOCI_NORM          0.00001
 #define GAMMA_INTERVALS       10
 /* definitions of migration model */
-#define MATRIX                 1	/*+ */
-#define MATRIX_SYMMETRIC      11	/*+ */
-#define MATRIX_SAMETHETA      12	/*+ */
-#define MATRIX_ARBITRARY      13	/*+ */
-#define ISLAND                 2	/*+ */
-#define ISLAND_VARTHETA       21	/*+ */
+#define MATRIX                 1 /*+ */
+#define MATRIX_SYMMETRIC      11 /*+ */
+#define MATRIX_SAMETHETA      12 /*+ */
+#define MATRIX_ARBITRARY      13 /*+ */
+#define ISLAND                 2 /*+ */
+#define ISLAND_VARTHETA       21 /*+ */
 #define STEPSTONE              3 /*- */
 #define CONTINUUM              4 /*- */
 #define NEIGHBOR               5 /*- */
 /* replication stuff */
-#define SINGLECHAIN            0	/*+ */
-#define MULTIPLECHAIN          1	/*+ */
-#define MULTIPLERUN            2	/*+ */
+#define SINGLECHAIN            0 /*+ */
+#define MULTIPLECHAIN          1 /*+ */
+#define MULTIPLERUN            2 /*+ */
 /* heating stuff */
 #define HEATED_CHAIN_NUM       4
 #define HEATED_THREAD_NUM      4
-#define COLD                   1	/*+ */
-#define WARM                   4	/*+ */
-#define HOT                    7	/*+ */
-#define VERYHOT                10	/*+ */
+#define COLD                   1 /*+ */
+#define WARM                   4 /*+ */
+#define HOT                    7 /*+ */
+#define VERYHOT                10 /*+ */
 /* maximization material*/
-#define SINGLELOCUS            0	/*+ */
-#define MULTILOCUS             1	/*+ */
-#define PROFILE                2	/*+ */
+#define SINGLELOCUS            0 /*+ */
+#define MULTILOCUS             1 /*+ */
+#define PROFILE                2 /*+ */
 /* print and plot material*/
-#define MAXPRINTVALLENGTH 16	/*+ maximal number of printpos */
-#define PLOTALL                0	/*+ plot to outfile and mathfile */
-#define PLOTOUTFILE            1	/*+ plot only to outifle */
-#define PLOT4NM                0	/*+ use 4Nm instead of M=m/mu */
-#define PLOTM                  1	/*+ use M=m/mu */
-#define PLOTSCALELOG           0	/*+ plot scale in log 10 units */
-#define PLOTSCALESTD           1	/*+ plot scale standard units */
-#define PLANEINTERVALS        36	/*+ intervals for plot */
-#define PLANESTART        0.0001	/*+ plot axes start */
-#define PLANEEND           100.0	/*+ plot axes end */
+#define MAXPRINTVALLENGTH 16 /*+ maximal number of printpos */
+#define PLOTALL                0 /*+ plot to outfile and mathfile */
+#define PLOTOUTFILE            1 /*+ plot only to outifle */
+#define PLOT4NM                0 /*+ use 4Nm instead of M=m/mu */
+#define PLOTM                  1 /*+ use M=m/mu */
+#define PLOTSCALELOG           0 /*+ plot scale in log 10 units */
+#define PLOTSCALESTD           1 /*+ plot scale standard units */
+#define PLANEINTERVALS        36 /*+ intervals for plot */
+#define PLANESTART        0.0001 /*+ plot axes start */
+#define PLANEEND           100.0 /*+ plot axes end */
 #define PAGEFEED               fprintf(outfile,"\n\f\n")
 #define PAGEFEEDWORLD               fprintf(world->outfile,"\n\f\n")
 #define PAGEFEEDW                   fprintf(universe[0]->outfile,"\n\f\n")
@@ -341,21 +346,21 @@ long chains is used */
 #define STOP                   1
 #define CONT                   3
 /* tree-print options */
-#define NONE                   0	/*+ */
-#define ALL                    1	/*+ */
-#define BEST                   2	/*+ */
-#define LASTCHAIN              3	/*+ */
+#define NONE                   0 /*+ */
+#define ALL                    1 /*+ */
+#define BEST                   2 /*+ */
+#define LASTCHAIN              3 /*+ */
 /* likelihood ration stuff*/
-#define LRATIO_STRINGS      1000	/*+ */
+#define LRATIO_STRINGS      1000 /*+ */
 /* profile likelihood stuff*/
 /* ALL and NONE are alread defined*/
-#define TABLES                 2	/*+ */
-#define SUMMARY                3	/*+ */
-#define MAX_PROFILE_TRIALS   100	/*+ */
+#define TABLES                 2 /*+ */
+#define SUMMARY                3 /*+ */
+#define MAX_PROFILE_TRIALS   100 /*+ */
 /* likelihood ratio stuff*/
 #define MLE 0
 #define ARBITRARY 1
-#define MAXPOP   100		/*n*(n-1)+n) */
+#define MAXPOP   100  /*n*(n-1)+n) */
 #define MAXPARAM 10000
 #define HEADER 1
 #define NOHEADER 0
