@@ -1,8 +1,21 @@
-// gamma deviated mutation rate among loci
-//
-//
-// code for the calculation of the gamma likelihood
-// and for its derivatives
+/*------------------------------------------------------
+Maximum likelihood estimation
+of migration rate  and effectice population size
+using a Metropolis-Hastings Monte Carlo algorithm
+-------------------------------------------------------
+ Gammalike and derivatives  R O U T I N E S
+ 
+ Peter Beerli 2001, Seattle
+ beerli@gs.washington.edu
+ 
+ Copyright 2001-2002 Peter Beerli and Joseph Felsenstein
+ 
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+$Id$
+*/
 #include "migration.h"
 #include "broyden.h"
 #include "combroyden.h"
@@ -65,7 +78,7 @@ gamma_loci_like_iterative(helper_fmt * helper, double *oparam, double *olparam,
   char save_a = nr->world->options->custm[nr->world->numpop2];
   //  if(save_a == 'c')
   // {
-  //	return  gamma_loci_like_old (helper, oparam, olparam, denom);
+  // return  gamma_loci_like_old (helper, oparam, olparam, denom);
   // }
   nr->world->options->custm[nr->world->numpop2]='c';
   nr->world->options->custm2[nr->world->numpop2]='c';
@@ -337,7 +350,7 @@ gamma_locus_derivative (helper_fmt * helper, long locus)
       ll = nr->probcat[r] + calc_locus_like (nr, nr->param, nr->lparam, locus);
       ll +=  -rate * alpha / theta1 + lograte * (alpha - 1.);
       //ll +=  -rate * alpha + lograte * (alpha - 1.);
-      gamma_parts_gradient (rate, helper->expxv, nr, locus);	//changes nr->parts
+      gamma_parts_gradient (rate, helper->expxv, nr, locus); //changes nr->parts
       //first of the derivatives: theta1
       //     tmp =  nr->parts[0];
       tmp = rate * alpha / (theta1 * theta1) + nr->parts[0];
@@ -376,7 +389,7 @@ gamma_locus_derivative (helper_fmt * helper, long locus)
       if (i == 0)
         {
           sumi =
-            //	    sumi * EXP (tempmax[i] - nr->locilikes[locus]);
+            //     sumi * EXP (tempmax[i] - nr->locilikes[locus]);
             sumi * EXP (tempmax[i] - nr->locilikes[locus]) - alpha / theta1;
         }
       else
@@ -405,13 +418,13 @@ gamma_parts_gradient (double x, double *param, nr_fmt * nr, long locus)
 
   //  double copysum=0;
   long pop, i;
-  double expapg;		//, summ;
+  double expapg;  //, summ;
   //double summm = 0.0;
   long msta, msto;
   double waitmig;
   double pointmig;
   tarchive_fmt *tl;
-  double *part;			//, df = 0.0;
+  double *part;   //, df = 0.0;
   //  double value ;
   double theta1 = param[0];
   double *geo = nr->world->data->geo;
