@@ -1,9 +1,6 @@
 /* Joint chain estimator
 Peter Beerli January 2000
  
-Copyright 2001 Peter Beerli and Joseph Felsenstein
- 
-$Id: joint-chains.c,v 1.16 2001/09/07 23:56:13 beerli Exp $
  
 like(param) = Sum_g^G   ( p(g|param)/ L(param_j))
  
@@ -14,13 +11,17 @@ denom = Sum_j^chains (n_j P(g|param0_j) / L(param_j)
 - solve paramlike iteratively
 - maximize paramlike
  
-coaliter
-    thetaval -> lthetai at theti[locus][lastchain]
-    cycle through interp   -> new lthetai using theti[locus][chain] 
-                      ((newth-lthetai)>epsilon) 
-    estimate_parameter last chain
-    estimate_parameter many chains
+ Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+$Id: joint-chains.c,v 1.16 2001/09/07 23:56:13 beerli Exp $
 */
 #include "migration.h"
 #include "broyden.h"
@@ -50,7 +51,7 @@ create_multiapg0 (double *apg0, nr_fmt * nr, long rep, long locus)
                           nr->world->atl[r][locus].lparam0,
                           &nr->world->atl[rep][locus].tl[g], nr, locus)
                    - (nr->world->chainlikes[locus][r]);
-          
+
           if (tmp[r] > tmpmax)
             tmpmax = tmp[r];
         }
@@ -76,7 +77,7 @@ interpolate_like (nr_fmt * nr, long locus)
   boolean diffdone;
   double *oldlike;
   double *chainlike = nr->world->chainlikes[locus];
-  oldlike = (double *) calloc (repdiff, sizeof (double));  
+  oldlike = (double *) calloc (repdiff, sizeof (double));
   memcpy (oldlike, chainlike, sizeof (double) * repdiff);
 
   newlike = (double *) calloc (repdiff, sizeof (double));
@@ -129,9 +130,9 @@ interpolate_like (nr_fmt * nr, long locus)
     }
   if ((nr->world->options->progress || diffdone) && delta > EPSILON)
     {
-	  printf ("           Reweighting operation converged to\n");
-	  printf ("           constant multiplier %f in %li cycles\n",
-		   delta, z);
+      printf ("           Reweighting operation converged to\n");
+      printf ("           constant multiplier %f in %li cycles\n",
+              delta, z);
     }
   free (newlike);
   free(oldlike);
