@@ -1,23 +1,28 @@
-/* 
+/*
    (mutation) rates following a Gamma distribution
    using orthogonal polynomials for finding rates and
    LOG(probabilities)
    [based on initgammacat of Joe Felsenstein]
-
+ 
    - Generalized Laguerre (routine by Joe Felsenstein 2000)
      defining points for a Gamma distribution with 
      shape parameter alpha and location parameter beta=1/alpha
      [mean=1, std = 1/alpha^2]
    - Hermite (approximates a normal and is activated when 
      the shape parameter alpha is > 100.)
-
+ 
    Part of Migrate (Lamarc package)
    http://evolution.genetics.washington.edu/lamarc.html
-
+ 
    Peter Beerli, Seattle 2001
    
 Copyright 2001 Peter Beerli and Joseph Felsenstein
-
+ 
+ 
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
 $Id: laguerre.c,v 1.7 2001/09/07 23:56:13 beerli Exp $
 */
 #include "migration.h"
@@ -46,7 +51,7 @@ gcc -DLAGUERRE_TEST -g laguerre.c -o laguerre -lm*/
 double
 logfac (long n)
 {
-  /* log(n!) values were calculated with Mathematica 
+  /* log(n!) values were calculated with Mathematica
      with a precision of 30 digits */
   switch (n)
     {
@@ -86,23 +91,23 @@ logfac (long n)
 double hermite (long n, double x);
 void root_hermite (long n, double *hroot);
 double halfroot (double (*func) (long m, double x),
-		 long n, double startx, double delta);
+                 long n, double startx, double delta);
 void hermite_weight (long n, double *hroot, double *weights);
 void inithermitcat (long categs, double alpha, double theta1,
-		    double *rate, double *probcat);
+                    double *rate, double *probcat);
 
 double glaguerre (long m, double b, double x);
 void initlaguerrecat (long categs, double alpha, double theta1,
-		      double *rate, double *probcat);
+                      double *rate, double *probcat);
 void roots_laguerre (long m, double b, double **lgroot);
 
 void initgammacat (long categs, double alpha, double theta1,
-		   double *rate, double *probcat);
+                   double *rate, double *probcat);
 
 void integrate_laguerre (long categs, double *rate,
-			 double *probcat,
-			 double (*func) (double theta, helper_fmt * b),
-			 helper_fmt * helper, double *result, double *rmax);
+                         double *probcat,
+                         double (*func) (double theta, helper_fmt * b),
+                         helper_fmt * helper, double *result, double *rmax);
 
 
 /*------------------------------------------------------
@@ -113,29 +118,29 @@ double
 glaguerre (long m, double b, double x)
 {
   long i;
-  double gln, glnm1, glnp1;	/* L_n, L_(n-1), L_(n+1) */
+  double gln, glnm1, glnp1; /* L_n, L_(n-1), L_(n+1) */
 
   if (m == 0)
     return 1.0;
   else
     {
       if (m == 1)
-	return 1.0 + b - x;
+        return 1.0 + b - x;
       else
-	{
-	  gln = 1.0 + b - x;
-	  glnm1 = 1.0;
-	  for (i = 2; i <= m; i++)
-	    {
-	      glnp1 =
-		((2 * (i - 1) + b + 1.0 - x) * gln - (i - 1 + b) * glnm1) / i;
-	      glnm1 = gln;
-	      gln = glnp1;
-	    }
-	  return gln;
-	}
+        {
+          gln = 1.0 + b - x;
+          glnm1 = 1.0;
+          for (i = 2; i <= m; i++)
+            {
+              glnp1 =
+                ((2 * (i - 1) + b + 1.0 - x) * gln - (i - 1 + b) * glnm1) / i;
+              glnm1 = gln;
+              gln = glnp1;
+            }
+          return gln;
+        }
     }
-}				/* glaguerre */
+}    /* glaguerre */
 
 
 /* calculates hermite polynomial with degree n and parameter x */
@@ -190,7 +195,7 @@ root_hermite (long n, double *hroot)
 */
 double
 halfroot (double (*func) (long m, double x),
-	  long n, double startx, double delta)
+          long n, double startx, double delta)
 {
   double xl;
   double xu;
@@ -200,7 +205,7 @@ halfroot (double (*func) (long m, double x),
   double fm = 100000.;
   double gradient;
   boolean down = FALSE;
-  /* decide if we search above or below startx and escapes to trace back 
+  /* decide if we search above or below startx and escapes to trace back
      to the starting point that most often will be 
      the root from the previous calculation */
   if (delta < 0)
@@ -222,52 +227,52 @@ halfroot (double (*func) (long m, double x),
     {
       /* is root outside of our bracket? */
       if ((fu < 0.0 && fl < 0.0) || (fu > 0.0 && fl > 0.0))
-	{
-	  xu += delta;
-	  fu = (*func) (n, xu);
-	  fl = (*func) (n, xl);
-	  gradient = (fl - fu) / (xl - xu);
-	  down = gradient < 0 ? TRUE : FALSE;
-	}
+        {
+          xu += delta;
+          fu = (*func) (n, xu);
+          fl = (*func) (n, xl);
+          gradient = (fl - fu) / (xl - xu);
+          down = gradient < 0 ? TRUE : FALSE;
+        }
       else
-	{
-	  xm = xl - fl / gradient;
-	  fm = (*func) (n, xm);
-	  if (down)
-	    {
-	      if (fm > 0.)
-		{
-		  xl = xm;
-		  fl = fm;
-		}
-	      else
-		{
-		  xu = xm;
-		  fu = fm;
-		}
-	    }
-	  else
-	    {
-	      if (fm > 0.)
-		{
-		  xu = xm;
-		  fu = fm;
-		}
-	      else
-		{
-		  xl = xm;
-		  fl = fm;
-		}
-	    }
-	  gradient = (fl - fu) / (xl - xu);
-	}
+        {
+          xm = xl - fl / gradient;
+          fm = (*func) (n, xm);
+          if (down)
+            {
+              if (fm > 0.)
+                {
+                  xl = xm;
+                  fl = fm;
+                }
+              else
+                {
+                  xu = xm;
+                  fu = fm;
+                }
+            }
+          else
+            {
+              if (fm > 0.)
+                {
+                  xu = xm;
+                  fu = fm;
+                }
+              else
+                {
+                  xl = xm;
+                  fl = fm;
+                }
+            }
+          gradient = (fl - fu) / (xl - xu);
+        }
     }
   return xm;
 }
 
 
 // calculate the weights for the hermite polynomial
-// at the roots 
+// at the roots
 // using formula Abramowitz and Stegun chapter 25.4.46 p.890
 void
 hermite_weight (long n, double *hroot, double *weights)
@@ -285,15 +290,15 @@ hermite_weight (long n, double *hroot, double *weights)
 /* calculates rates and LOG(probabilities) */
 void
 inithermitcat (long categs, double alpha, double theta1,
-	       double *rate, double *probcat)
+               double *rate, double *probcat)
 {
   long i;
   double *hroot;
   double std = SQRT2 * theta1 / sqrt (alpha);
   hroot = (double *) calloc (categs + 1, sizeof (double));
-  root_hermite (categs, hroot);	// calculate roots
-  hermite_weight (categs, hroot, probcat);	// set weights
-  for (i = 0; i < categs; i++)	// set rates
+  root_hermite (categs, hroot); // calculate roots
+  hermite_weight (categs, hroot, probcat); // set weights
+  for (i = 0; i < categs; i++) // set rates
     {
       rate[i] = theta1 + std * hroot[i];
       probcat[i] = log (probcat[i]);
@@ -304,7 +309,7 @@ inithermitcat (long categs, double alpha, double theta1,
 void
 roots_laguerre (long m, double b, double **lgroot)
 {
-  /* For use by initgammacat.  
+  /* For use by initgammacat.
      Get roots of m-th Generalized Laguerre polynomial, given roots 
      of (m-1)-th, these are to be stored in lgroot[m][] */
   long i;
@@ -320,59 +325,59 @@ roots_laguerre (long m, double b, double **lgroot)
     {
       dwn = TRUE;
       for (i = 1; i <= m; i++)
-	{
-	  if (i < m)
-	    {
-	      if (i == 1)
-		lower = 0.0;
-	      else
-		lower = lgroot[m - 1][i - 1];
-	      upper = lgroot[m - 1][i];
-	    }
-	  else
-	    {			/* i == m, must search above */
-	      lower = lgroot[m - 1][i - 1];
-	      x = lgroot[m - 1][m - 1];
-	      do
-		{
-		  x = 2.0 * x;
-		  y = glaguerre (m, b, x);
-		}
-	      while ((dwn && (y > 0.0)) || ((!dwn) && (y < 0.0)));
-	      upper = x;
-	    }
-	  while (upper - lower > 0.000000001)
-	    {
-	      x = (upper + lower) / 2.0;
-	      if ((tmp = glaguerre (m, b, x)) > 0.0)
-		{
-		  if (dwn)
-		    lower = x;
-		  else
-		    upper = x;
-		}
-	      else
-		{
-		  if (dwn)
-		    upper = x;
-		  else
-		    lower = x;
-		}
-	    }
-	  lgroot[m][i] = (lower + upper) / 2.0;
-	  dwn = !dwn;		/* switch for next one */
-	}
+        {
+          if (i < m)
+            {
+              if (i == 1)
+                lower = 0.0;
+              else
+                lower = lgroot[m - 1][i - 1];
+              upper = lgroot[m - 1][i];
+            }
+          else
+            {   /* i == m, must search above */
+              lower = lgroot[m - 1][i - 1];
+              x = lgroot[m - 1][m - 1];
+              do
+                {
+                  x = 2.0 * x;
+                  y = glaguerre (m, b, x);
+                }
+              while ((dwn && (y > 0.0)) || ((!dwn) && (y < 0.0)));
+              upper = x;
+            }
+          while (upper - lower > 0.000000001)
+            {
+              x = (upper + lower) / 2.0;
+              if ((tmp = glaguerre (m, b, x)) > 0.0)
+                {
+                  if (dwn)
+                    lower = x;
+                  else
+                    upper = x;
+                }
+              else
+                {
+                  if (dwn)
+                    upper = x;
+                  else
+                    lower = x;
+                }
+            }
+          lgroot[m][i] = (lower + upper) / 2.0;
+          dwn = !dwn;  /* switch for next one */
+        }
     }
-}				/* root_laguerre */
+}    /* root_laguerre */
 
 
 void
 initgammacat (long categs, double alpha, double theta1,
-	      double *rate, double *probcat)
+              double *rate, double *probcat)
 {
-/* calculate rates and probabilities to approximate Gamma distribution
-   of rates with "categs" categories and shape parameter "alpha" using
-   rates and weights from Generalized Laguerre quadrature */
+  /* calculate rates and probabilities to approximate Gamma distribution
+     of rates with "categs" categories and shape parameter "alpha" using
+     rates and weights from Generalized Laguerre quadrature */
 
   if (alpha >= 100.)
     {
@@ -386,10 +391,10 @@ initgammacat (long categs, double alpha, double theta1,
 
 void
 initlaguerrecat (long categs, double alpha, double theta1, double *rate,
-		 double *probcat)
+                 double *probcat)
 {
   long i;
-  double **lgroot;		/* roots of GLaguerre polynomials */
+  double **lgroot;  /* roots of GLaguerre polynomials */
   double f, x, xi, y;
 
   lgroot = (double **) calloc (categs + 1, sizeof (double *));
@@ -401,9 +406,9 @@ initlaguerrecat (long categs, double alpha, double theta1, double *rate,
     }
   lgroot[1][1] = 1.0 + alpha;
   for (i = 2; i <= categs; i++)
-    roots_laguerre (i, alpha, lgroot);	/* get roots for L^(a)_n */
+    roots_laguerre (i, alpha, lgroot); /* get roots for L^(a)_n */
   /* here get weights */
-  /* Gamma weights are 
+  /* Gamma weights are
      (1+a)(1+a/2) ... (1+a/n)*x_i/((n+1)^2 [L_{n+1}^a(x_i)]^2)  */
   f = 1;
   for (i = 1; i <= categs; i++)
@@ -423,14 +428,14 @@ initlaguerrecat (long categs, double alpha, double theta1, double *rate,
     }
   free (lgroot[0]);
   free (lgroot);
-}				/* initgammacat */
+}    /* initgammacat */
 
 
 void
 integrate_laguerre (long categs, double *rate,
-		    double *probcat,
-		    double (*func) (double theta, helper_fmt * b),
-		    helper_fmt * helper, double *result, double *rmax)
+                    double *probcat,
+                    double (*func) (double theta, helper_fmt * b),
+                    helper_fmt * helper, double *result, double *rmax)
 {
   double summ = 0.;
   long i;
@@ -445,7 +450,7 @@ integrate_laguerre (long categs, double *rate,
       temp[i] = (*func) (rate[i], (void *) helper);
       stemp[i] = helper->sign;
       if (temp[i] > *rmax)
-	*rmax = temp[i];
+        *rmax = temp[i];
     }
   for (i = 0; i < categs; i++)
     {
