@@ -11,6 +11,10 @@
  
  Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
 $Id: lrt.c,v 1.13 2001/07/25 19:27:24 beerli Exp $
  
 -------------------------------------------------------*/
@@ -101,6 +105,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
     }
   else
     {
+      world->locus=0;
       locus = 0;
     }
   PAGEFEEDWORLD;
@@ -120,7 +125,7 @@ print_lratio_test (world_fmt * world, long *Gmax)
                           maxnum, header,
                           world->options->lratio->data[c].value1, NULL);
         }
-      else			/*arbitrary */
+      else   /*arbitrary */
         {
           df = set_test_param (param0, world->options->lratio->data[c].value1,
                                world, 0, -1, maxwhich, &maxnum, &zeros);
@@ -254,7 +259,7 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df,
     }
   sprintf (temp, "=assumed to be equal to=");
   strcat (teststat, temp);
-  part1len = 43;		//strlen (teststat);
+  part1len = 43;  //strlen (teststat);
   length = MAX (0, 5 - sprintf (tmp, "%i", ((int) param1[0])));
   sprintf (temp, "\n        %.*f", length, param1[0]);
   strcat (teststat, temp);
@@ -276,7 +281,7 @@ test_locus_like (nr_fmt * nr, double *param0, double *param1, long df,
     }
   //  sprintf (temp, "}");
   //  strcat (teststat, temp);
-  part2len = 43;		// strlen (teststat);
+  part2len = 43;  // strlen (teststat);
   spaces = 43 - 5 * (1 + world->numpop);
   strcpy (spacer, "                          ");
 
@@ -418,7 +423,7 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df,
   else
     sprintf (temp, "%-9.2f  %3li %8.5f %s\n", testval, df, chiprob, message);
   strcat (teststat, temp);
-  part1len = 43;		//strlen (teststat);
+  part1len = 43;  //strlen (teststat);
   length = MAX (0, 5 - sprintf (tmp, "%i", ((int) param1[0])));
   sprintf (temp, "   %.*f", length, param1[0]);
   strcat (teststat, temp);
@@ -439,7 +444,7 @@ test_loci_like (nr_fmt * nr, double *param0, double *param1, long df,
         strcat (teststat, "\n  ");
     }
   //  sprintf (temp, "}");
-  part2len = 43;		//strlen (teststat);
+  part2len = 43;  //strlen (teststat);
   spaces = 43 - 5 * (1 + world->numpop);
 
   strcpy (spacer, "                          ");
