@@ -3,21 +3,25 @@ Maximum likelihood estimation
 of migration rate  and effectice population size
 using a Metropolis-Hastings Monte Carlo algorithm
 -------------------------------------------------------
-	M A I N   P R O G R A M
+ M A I N   P R O G R A M
  
-	drives the whole program MIGRATE.
+ drives the whole program MIGRATE.
  
  for options of the program: README and parmfile.distrib,
-	options.c
+ options.c
 and of course the documentation at:
-					   http://evolution.genetics.washington.edu/lamarc/migrate.html
+        http://evolution.genetics.washington.edu/lamarc/migrate.html
  
-	Peter Beerli, started 1997, Seattle
-	beerli@genetics.washington.edu
+ Peter Beerli, started 1997, Seattle
+ beerli@genetics.washington.edu
  
-	Copyright 2001 Peter Beerli and Joseph Felsenstein
+ Copyright 2001 Peter Beerli and Joseph Felsenstein
  
-						$Id: main.c,v 1.76 2001/09/07 23:56:13 beerli Exp $
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+$Id: main.c,v 1.76 2001/09/07 23:56:13 beerli Exp $
 -------------------------------------------------------*/
 #include "migration.h"
 #include "definitions.h"
@@ -44,6 +48,10 @@ and of course the documentation at:
 #ifdef DMALLOC_FUNC_CHECK
 #include <dmalloc.h>
 #endif
+//use this if you have nice() and need to be nice with others
+#ifdef HAVE_NICE
+#include <unistd.h>
+#endif
 //
 #define EARTH  universe[0]
 #define VENUS  universe[1]
@@ -51,21 +59,16 @@ and of course the documentation at:
 #define SUN    universe[3]
 
 /* GLOBAL VARIABLES +++++++++++++++++++++++++++++++++++++ */
-int             myID;		/* used if MPI is running otherwise == 0       */
+int             myID;  /* used if MPI is running otherwise == 0       */
 //int           allID;
-int             color;		/* either 1 or MPI_UNDEFINED */
-int             numcpu;		/* used if MPI is running otherwise == 1     */
-int             numlocicpu;
-int             locidone;	/* used in MPI workers */
-//MPI_Comm comm_all_worlds;
+int             color;  /* either 1 or MPI_UNDEFINED */
+int             numcpu;  /* used if MPI is running otherwise == 1     */
+int             locidone; /* used in MPI workers */
 #ifdef MPI
 MPI_Comm        comm_world;
-//MPI_Comm comm_all_worlds;
-//MPI_Comm comm_otherworld;
 #endif
 #ifdef SLOWNET
-int             profiledone;	/* used in MPI workers in profiles on slow
-				 * networks */
+int             profiledone; /* used in MPI workers in profiles on slow networks */
 #endif
 #ifdef PTHREADS
 tpool_t         heating_pool;
@@ -198,35 +201,30 @@ main(int argc, char **argv)
   char           *this_string;
   char            type = 's';
   data_fmt       *data;
-  //unused in all compile variants ? int i;
   int             usize = HEATED_CHAIN_NUM;
   long            Gmax = 0;
   long            outfilepos = 0;
   option_fmt     *options;
   world_fmt     **universe;
+#ifdef HAVE_NICE
+  nice(10);  //nice value arbitrarily set to 10, 5 is still nice, 0 is standard
+#endif
 #ifdef MPI
-  //long          maxreplicate;
-  //printf("just started before init\n");
+  // parallel version
   MPI_Init(&argc, &argv);
-  //comm_all_worlds = MPI_COMM_WORLD;
-  //MPI_Comm_size(comm_all_worlds, &numcpu);
-  //MPI_Comm_rank(comm_all_worlds, &allID);
   comm_world = MPI_COMM_WORLD;
   MPI_Comm_size(comm_world, &numcpu);
   MPI_Comm_rank(comm_world, &myID);
   MPI_Barrier(comm_world);
-  //seems to be necessary on scyld beowulf clusters
-  // myID = allID;
 #ifdef SLOWNET
-
+  // slow network parallel version
   profiledone = 0;
   which_calc_like(SINGLELOCUS);
 #endif
 #else
-
+  //scalar version of migrate
   myID = MASTER;
   numcpu = 1;
-  numlocicpu = 1;
 #endif
   //random number seed global inits
   seed = malloc(sizeof(long) * 3);
@@ -247,6 +245,9 @@ main(int argc, char **argv)
 
   /* parmfile and menu ------------------------------------------ */
   init_options(options);
+  if(argc>1) //if user want to use a different parmfile than the default
+	  strncpy(options->parmfilename, argv[1], strlen(argv[1])+1);
+
 #ifdef MPI
 
   if (myID == MASTER)
@@ -324,9 +325,9 @@ main(int argc, char **argv)
             print_lratio_test(EARTH, &Gmax);
 
           if (options->aic)
-			{
-			  akaike_information(EARTH, &Gmax);
-			}
+            {
+              akaike_information(EARTH, &Gmax);
+            }
 #ifdef MPI
 
         }
@@ -363,18 +364,18 @@ main(int argc, char **argv)
       //stop workers
     }
 #ifdef PRIVATE
-  master_gridder(world, &Gmax);
+  //    master_gridder(world, &Gmax);
 #endif
 
   profile_tables(options, EARTH, &Gmax);
 #else
-#ifdef MPI			/* WORKS */
+#ifdef MPI   /* WORKS */
 
   if (myID == MASTER)
     {
 #endif
 #ifdef PRIVATE
-      master_gridder(EARTH, &Gmax);
+      //       master_gridder(EARTH, &Gmax);
 #endif
 
       profile_tables(options, EARTH, &Gmax);
@@ -382,7 +383,7 @@ main(int argc, char **argv)
 
     }
 #endif
-#endif				/* SLOWNET */
+#endif    /* SLOWNET */
   if (myID == MASTER)
     {
       print_finish(EARTH, outfilepos);
@@ -408,9 +409,9 @@ main(int argc, char **argv)
   MPI_Finalize();
 #endif
 
-  apocalypse_now(EARTH);
+  //free_universe(universe, usize);
   return 0;
-}				/* main end */
+}    /* main end */
 
 /* ============================================================= */
 /* multiple loci combination ---------------------------------- */
@@ -423,13 +424,13 @@ combine_loci(char type, option_fmt * options, world_fmt * world, long *Gmax)
 
   long            kind = MULTILOCUS;
   if (options->readsum)
-  {
-	  if (world->loci == 1)
-		{
-		  kind = SINGLELOCUS;
-		  //return;
-		}
-  }
+    {
+      if (world->loci == 1)
+        {
+          kind = SINGLELOCUS;
+          //return;
+        }
+    }
 #if MPI
 
   if ((world->loci - world->skipped > 0) || (options->readsum))
@@ -1100,7 +1101,7 @@ analyze_olddata(world_fmt * world,
   long            Gmax = 0;
   if (myID == MASTER)
     {
-	  unset_penalizer_function(TRUE);
+      unset_penalizer_function(TRUE);
       Gmax = read_savesum(world, options, data);
 #ifdef MPI
 
@@ -1110,8 +1111,8 @@ analyze_olddata(world_fmt * world,
   else
     {
       MPI_Bcast(listofthings, 6, MPI_LONG, MASTER, comm_world);
-//      printf("listofthings received\n");
-  //    fflush(stdout);
+      //      printf("listofthings received\n");
+      //    fflush(stdout);
       world->loci = listofthings[0];
       world->numpop = listofthings[1];
       world->numpop2 = listofthings[2];
@@ -1177,7 +1178,9 @@ analyze_olddata(world_fmt * world,
 void
 profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
 {
+  long len;
 #ifndef SLOWNET
+
   long            i;
 #endif
 
@@ -1191,6 +1194,12 @@ profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
 
       time(&world->starttime);
 #endif
+
+      len = world->numpop2 + (world->options->gamma ? 1 : 0);
+#ifdef LONGSUM
+
+      len += world->numpop*3;
+#endif /*LONGSUM*/
 #ifdef SLOWNET
 
       if (!options->readsum)
@@ -1204,17 +1213,15 @@ profile_tables(option_fmt * options, world_fmt * world, long *gmaxptr)
       if (myID == MASTER)
         {
           print_profile_title(world);
-          mpi_profiles_master(world,
-                              world->numpop2 +
-                              (world->options->gamma ? 1 : 0),
-                              world->profilewho);
+          mpi_profiles_master(world, len, world->profilewho);
         }
       else
         mpi_profiles_worker(world, gmaxptr);
 #else
 
       print_profile_title(world);
-      for (i = 0; i < world->numpop2 + (world->options->gamma ? 1 : 0); i++)
+
+      for (i = 0; i < len; i++)
         {
           print_profile_likelihood_driver(i, world, gmaxptr);
           fprintf(world->outfile, "%s\n\n", world->buffer);
@@ -1262,8 +1269,8 @@ setup_locus(long locus, world_fmt * world, option_fmt * options,
       if (strchr(SNPTYPES, options->datatype))
         {
           if (options->datatype == 'u')
-            data->seq->endsite *= (data->seq->addon + 1);
-          data->seq->endsite += data->seq->addon;
+            world->data->seq->endsite *= (data->seq->addon + 1);
+          world->data->seq->endsite += data->seq->addon;
         }
     }
   if (!options->replicate
@@ -1272,7 +1279,7 @@ setup_locus(long locus, world_fmt * world, option_fmt * options,
     {
       //free_datapart(data, options, locus);
       if (data->skiploci[locus])
-        {	/* skip loci with no tips */
+        { /* skip loci with no tips */
           //cleanup_world(world, locus);
           return 0;
         }
@@ -1300,7 +1307,7 @@ setup_locus(long locus, world_fmt * world, option_fmt * options,
       //world->ueplikelihood);
     }
 #endif
-  world->allikemax = -DBL_MAX;	/* for best tree option */
+  world->allikemax = -DBL_MAX; /* for best tree option */
   return 1;
 }
 
