@@ -11,6 +11,10 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
 $Id: menu.c,v 1.51 2001/09/07 23:56:13 beerli Exp $
  
 -------------------------------------------------------*/
@@ -81,6 +85,10 @@ print_menu_title (FILE * file, option_fmt * options)
 
       fprintf (file, "  compiled for a PARALLEL COMPUTER ARCHITECTURE\n");
 #endif
+#ifdef ALTIVEC
+
+      fprintf (file, "  compiled for a ALTIVEC\n");
+#endif
 
       fprintf (file, "  Version %s\n", MIGRATEVERSION);
       get_time (nowstr, "  %c");
@@ -229,12 +237,12 @@ get_menu (option_fmt * options)
       if (options->usertree && !strchr (SEQUENCETYPES, options->datatype))
         options->usertree = FALSE;
       if (options->dist && !strchr (SEQUENCETYPES, options->datatype))
-        options->dist = FALSE;	//prevents incompatability
+        options->dist = FALSE; //prevents incompatability
       // of tree and distance designation, only for
       // sequence data the datalines and tree-tips can match
       // msats or EP data is ambiguos concerning the tree.
     }
-  if (options->datatype == 'g')	//prevents overwriting sumfile
+  if (options->datatype == 'g') //prevents overwriting sumfile
     options->writesum = FALSE;
 
 #ifdef UEP
@@ -411,7 +419,7 @@ menuData (option_fmt * options, char datatype[])
               //printf ("  [the bigger the longer the run and the more accurate the estimate]\n");
               //fscanf (stdin, "%ld%*[^\n]", &options->micro_stepnum);
               //break;
-            case 2:		/*micro-threshold */
+            case 2:  /*micro-threshold */
               printf ("  What is the threshold value?\n");
               printf
               ("  E.g. if your allele is 24 and the threshold is 10\n");
@@ -549,7 +557,7 @@ menuInput (option_fmt * options)
   long len, test = 0;
   unsigned long timeseed;
   char input[LINESIZE];
-  char answer;			//, ch;
+  char answer;   //, ch;
   char *stringstep, *string2, *string3, *string4;
   char treestr[4][20] = { "None", "All", "Best", "Last chain" };
   char progress[3][8] = { "Verbose", "Yes", "No" };
@@ -993,7 +1001,7 @@ menuInput (option_fmt * options)
                   FGETS (input, LINESIZE, stdin);
                 }
               while (strchr ("pdqf", (int) lowercase (input[0])) == NULL);
-              switch (lowercase (input[0]))	// in strchr removed s
+              switch (lowercase (input[0])) // in strchr removed s
                 {
                 case 'p':
                   options->profilemethod = 'p';
@@ -1494,7 +1502,7 @@ menuParameters (option_fmt * options)
         case '6':
           options->printfst = !options->printfst;
           break;
-        case '7':		/* fill in the custom migration matrix */
+        case '7':  /* fill in the custom migration matrix */
           read_custom_menu_migration (options);
           break;
         case '8':
@@ -1862,7 +1870,7 @@ display_lrt_syntax (void)
   printf ("      s = averages of MIGRATION RATES from i->j and j->i\n");
   printf ("      m = averages of THETAS or MIGRATION RATES [!!!]\n");
   printf ("      value = specify your own value\n\n");
-  printf ("  [If you want to leave this editor, type \"quit\" or \"end\" and <return>\n");	// To review the Syntax type \"syntax\"\n");
+  printf ("  [If you want to leave this editor, type \"quit\" or \"end\" and <return>\n"); // To review the Syntax type \"syntax\"\n");
 }
 
 char
