@@ -1,9 +1,17 @@
 /*
- * mig-histogram code
- *
- *
- * $Id$
- *
+  mig-histogram code
+ 
+  Peter Beerli
+  beerli@gs.washington.edu
+ 
+    Copyright 2002 Peter Beerli
+ 
+  This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+  $Id$
+ 
  */
 
 #include "mig-histogram.h"
@@ -91,7 +99,7 @@ print_mighist_output (FILE * out, world_fmt * world, double ***migtable,
   for (loc = 0; loc < world->loci; loc++)
     total[world->loci] += total[loc];
   for (loc = 0; loc < loci1; loc++)
-    {				/* Each locus + Summary */
+    {    /* Each locus + Summary */
       if (loc != world->loci)
         fprintf (out, "Locus %li\n", loc + 1);
       else
@@ -544,8 +552,8 @@ print_histogram_ascii (FILE * out, histogram_fmt ** histogram,
   //double        sum = 0;
   double time;
   long weight;
-  binning = (double *) calloc (bins, sizeof (double));
-  binvec = (double *) calloc (bins, sizeof (double));
+  binning = (double *) calloc (bins+1, sizeof (double));
+  binvec = (double *) calloc (bins+1, sizeof (double));
 
   for (loc = 0; loc < loci; loc++)
     {
@@ -575,7 +583,7 @@ print_histogram_ascii (FILE * out, histogram_fmt ** histogram,
           if (migtable[loc][i][2] == NOAVERAGE)
             continue;
           //no event for this migration i->j
-          memset (binvec, 0, sizeof (double) * bins);
+          memset (binvec, 0, sizeof (double) * (bins+1));
           for (j = 0; j < histogram[loc][i].count; j++)
             {
               time = histogram[loc][i].time[j];
