@@ -5,6 +5,11 @@
    
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+ 
 $Id: migrate_mpi.c,v 1.11 2001/09/07 23:56:13 beerli Exp $
 */
 #ifdef MPI
@@ -31,7 +36,7 @@ void unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options);
 void pack_allele_data (char **buffer, long *bufsize, data_fmt * data,
                        long pop, long ind);
 void pack_sequence_data (char **buffer, long *bufsize, data_fmt * data,
-                         long pop, long ind);
+                         long pop, long ind, long locus);
 void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 void mpi_results_master (double sendtype, world_fmt * world,
                          long maxrep,
@@ -74,12 +79,12 @@ mpi_runloci_master (long loci, int *who)
         }
       else
         {
-          MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world);	//stop worker do wait for new loci
+          MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world); //stop worker do wait for new loci
         }
     }
   for (sender = MIN (loci, numcpu - 1) + 1; sender < numcpu; sender++)
     {
-      MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world);	//stop worker do wait for new loci
+      MPI_Send (&loci, 1, MPI_LONG, sender, 0, comm_world); //stop worker do wait for new loci
     }
 }
 
@@ -97,7 +102,7 @@ mpi_runloci_worker (world_fmt ** universe, int usize,
     {
       MPI_Recv (&locus, 1, MPI_LONG, MASTER, MPI_ANY_TAG,
                 comm_world, &status);
-      if (status.MPI_TAG != 0)	//stop condition
+      if (status.MPI_TAG != 0) //stop condition
         {
           run_locus (universe, usize, options, data,
                      heating_pool, maxreplicate, locus, treefilepos, Gmax);
@@ -194,7 +199,7 @@ mpi_likelihood_worker (world_fmt * world, helper_fmt * helper, long rep)
       if (!world->options->gamma)
         {
           nr->locilikes[locus] =
-            calc_locus_like (nr, param, lparam, locus) - mu_rates[locus];
+            calc_locus_like (nr, param, lparam, locus) + mu_rates[locus];
         }
       else
         {
@@ -269,7 +274,7 @@ mpi_send_stop (world_fmt * world)
   temp[0] = MIGMPI_END;
   for (worker = 1; worker < numcpu; worker++)
     {
-      MPI_Send (temp, (int) numelem2+2, MPI_DOUBLE, worker, 0, comm_world);	//end of loci
+      MPI_Send (temp, (int) numelem2+2, MPI_DOUBLE, worker, 0, comm_world); //end of loci
     }
   free (temp);
 }
@@ -282,7 +287,7 @@ mpi_send_stop_tag (int worker, world_fmt * world)
   long numelem2 = 2 * numelem;
   temp = (double *) calloc (numelem2+2, sizeof (double));
   temp[0] = MIGMPI_END;
-  MPI_Send (temp, (int) numelem2+2, MPI_DOUBLE, worker, 0, comm_world);	//end of loci
+  MPI_Send (temp, (int) numelem2+2, MPI_DOUBLE, worker, 0, comm_world); //end of loci
   free (temp);
 }
 
@@ -492,6 +497,7 @@ pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
 {
   long locus, pop, ind;
   long bufsize = 0;
+  long biggest;
 #ifdef UEP
 
   long sumtips, i;
@@ -519,21 +525,46 @@ pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
   // population data
   for (pop = 0; pop < data->numpop; pop++)
     {
-      sprintf (fp, "%li %s\n", data->numind[pop][FLOC], data->popnames[pop]);
+      sprintf (fp, "%s\n", data->popnames[pop]);
       bufsize += strlen (fp) + 1;
       *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
       strcat (*buffer, fp);
-      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      biggest = 0;
+      for(locus=0; locus<data->loci; locus++)
         {
-          sprintf (fp, "%*.*s\n", (int) options->nmlength,
-                   (int) options->nmlength, data->indnames[pop][ind]);
+          sprintf (fp, "%li\n", data->numalleles[pop][locus]);
+          if(biggest < data->numalleles[pop][locus])
+            biggest = data->numalleles[pop][locus];
           bufsize += strlen (fp) + 1;
           *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
           strcat (*buffer, fp);
-          if (strchr (SEQUENCETYPES, options->datatype))
-            pack_sequence_data (buffer, &bufsize, data, pop, ind);
-          else
-            pack_allele_data (buffer, &bufsize, data, pop, ind);
+        }
+      if (!strchr (SEQUENCETYPES, options->datatype))
+        {
+          for (ind = 0; ind < data->numind[pop][biggest]; ind++)
+            {
+              sprintf (fp, "%*.*s\n", (int) options->nmlength,
+                       (int) options->nmlength, data->indnames[pop][ind]);
+              bufsize += strlen (fp) + 1;
+              *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+              strcat (*buffer, fp);
+              pack_allele_data (buffer, &bufsize, data, pop, ind);
+            }
+        }
+      else
+        {
+          for(locus=0;locus<data->loci; ++locus)
+            {
+              for (ind = 0; ind < data->numalleles[pop][locus]; ind++)
+                {
+                  sprintf (fp, "%*.*s\n", (int) options->nmlength, (int) options->nmlength,
+                           data->indnames[pop][ind]);
+                  bufsize += strlen (fp) + 1;
+                  *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
+                  strcat (*buffer, fp);
+                  pack_sequence_data (buffer, &bufsize, data, pop, ind, locus);
+                }
+            }
         }
     }
   // geofile
@@ -553,7 +584,7 @@ pack_databuffer (char **buffer, data_fmt * data, option_fmt * options)
     {
       sumtips = 0;
       for (pop = 0; pop < data->numpop; ++pop)
-        sumtips += data->numind[pop][FLOC];
+        sumtips += data->numind[pop][0];//Assumes UEP is matched by locus 1
       sprintf (fp, "%li %li\n", sumtips, data->uepsites);
       bufsize += strlen (fp) + 1;
       *buffer = (char *) realloc (*buffer, sizeof (char) * bufsize);
@@ -611,19 +642,19 @@ pack_allele_data (char **buffer, long *bufsize, data_fmt * data, long pop,
 
 void
 pack_sequence_data (char **buffer, long *bufsize, data_fmt * data, long pop,
-                    long ind)
+                    long ind, long locus)
 {
   char *fp;
-  long locus;
-  fp = calloc (1, sizeof (char));
-  for (locus = 0; locus < data->loci; locus++)
-    {
-      fp = (char *) realloc (fp, (2+data->seq->sites[locus]) * sizeof (char));
-      sprintf (fp, "%s\n", data->yy[pop][ind][locus][0]);
-      *bufsize += 2+data->seq->sites[locus];
-      *buffer = (char *) realloc (*buffer, sizeof (char) * *bufsize);
-      strcat (*buffer, fp);
-    }
+  //  long locus;
+  //  fp = calloc (1, sizeof (char));
+  // for (locus = 0; locus < data->loci; locus++)
+  //   {
+  fp = (char *) calloc ((2 + data->seq->sites[locus]), sizeof (char));
+  sprintf (fp, "%s\n", data->yy[pop][ind][locus][0]);
+  *bufsize += 2 + data->seq->sites[locus];
+  *buffer = (char *) realloc (*buffer, sizeof (char) * *bufsize);
+  strcat (*buffer, fp);
+  //   }
   free (fp);
 }
 
@@ -632,6 +663,7 @@ void
 unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
 {
   long locus, pop, ind, i;
+  long biggest;
 #ifdef UEP
 
   long sumtips;
@@ -654,30 +686,25 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
   sgets (input, LINESIZE, &buf);
   sscanf (input, "%li%lf", &data->seq->addon, &data->seq->fracchange);
   // population data
+  biggest=0;
   for (pop = 0; pop < data->numpop; pop++)
     {
       sgets (input, LINESIZE, &buf);
-      sscanf (input, "%li%s", &data->numind[pop][FLOC], data->popnames[pop]);
-      init_data_structure2 (&data, options, pop);
-      for (ind = 0; ind < data->numind[pop][FLOC]; ind++)
+      sscanf (input, "%s", data->popnames[pop]);
+      for(locus=0; locus<data->loci; locus++)
         {
           sgets (input, LINESIZE, &buf);
-          sscanf (input, "%s", data->indnames[pop][ind]);
-          if (strchr (SEQUENCETYPES, options->datatype))
-            {
-              for (locus = 0; locus < data->loci; locus++)
-                {
-                  input =
-                    (char *) realloc (input,
-                                      sizeof (char) * (100 +
-                                                       data->seq->
-                                                       sites[locus]));
-                  sgets (input, 100 + data->seq->sites[locus], &buf);
-                  sscanf (input, "%s", data->yy[pop][ind][locus][0]);
-                }
-            }
-          else
+          sscanf (input, "%li", &data->numalleles[pop][locus]);
+          if(biggest<data->numalleles[pop][locus])
+            biggest = data->numalleles[pop][locus];
+        }
+      init_data_structure2 (&data, options, pop);
+      if (!strchr (SEQUENCETYPES, options->datatype))
+        {
+          for (ind = 0; ind < data->numind[pop][biggest]; ind++)
             {
+              sgets (input, LINESIZE, &buf);
+              sscanf (input, "%s", data->indnames[pop][ind]);
               for (locus = 0; locus < data->loci; locus++)
                 {
                   sgets (input, LINESIZE, &buf);
@@ -686,6 +713,20 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
                 }
             }
         }
+      else
+        {
+          for (locus = 0; locus < data->loci; locus++)
+            {
+              for (ind = 0; ind < data->numalleles[pop][locus]; ind++)
+                {
+                  sgets (input, LINESIZE, &buf);
+                  sscanf (input, "%s", data->indnames[pop][ind]);
+                  input =(char *) realloc (input, sizeof (char) * (100 + data->seq->sites[locus]));
+                  sgets (input, 100 + data->seq->sites[locus], &buf);
+                  sscanf (input, "%s", data->yy[pop][ind][locus][0]);
+                }
+            }
+        }
     }
   // geofile
   data->geo =
@@ -746,13 +787,20 @@ unpack_databuffer (char *buffer, data_fmt * data, option_fmt * options)
 #endif
   init_data_structure3 (data);
   /* replace this, if loci can have different number of ind */
+#ifndef NEWSTYLE
+
   set_numind (data);
+#endif
+
   switch (options->datatype)
     {
     case 'a':
       create_alleles (data);
       break;
     case 'b':
+		for (pop = 0; pop < data->loci; pop++)
+			data->maxalleles[pop] = XBROWN_SIZE;
+		break;
     case 'm':
       create_alleles (data);
       for (pop = 0; pop < data->loci; pop++)
@@ -767,12 +815,15 @@ unpack_result_buffer (char *buffer, world_fmt * world,
                       long locus, long maxrep, long numpop)
 {
   long rep, pop;
+  long addon=0;
   timearchive_fmt **atl = world->atl;
   double ***apg0 = world->apg0;
   char *input;
   char *buf = buffer;
   input = (char*) calloc(LINESIZE,sizeof(char));
-  for (rep = 0; rep < maxrep; rep++)
+  if (maxrep>1)
+    addon=1;
+  for (rep = 0; rep < maxrep + addon; rep++)
     {
       sgets (input, LINESIZE, &buf);
       atl[rep][locus].param_like = atof (input);
@@ -800,14 +851,18 @@ pack_result_buffer (char **buffer, world_fmt * world,
 {
   long rep, pop;
   char *input;
+  long addon=0;
   timearchive_fmt **atl = world->atl;
   double ***apg0 = world->apg0;
-  long bufsize = 1;		//maxrep * (1 + 4*numpop*numpop + world->options->lsteps) * 42 ;
+  long bufsize = 1;  //maxrep * (1 + 4*numpop*numpop + world->options->lsteps) * 42 ;
   input = (char*) calloc(LINESIZE,sizeof(char));
   (*buffer) = (char *) realloc (*buffer, sizeof (char) * bufsize);
   memset (*buffer, 0, sizeof (char) * bufsize);
   strcpy (input, "");
-  for (rep = 0; rep < maxrep; rep++)
+  if (maxrep>1)
+    addon=1;
+
+  for (rep = 0; rep < maxrep + addon; rep++)
     {
       sprintf (input, "%20.20f\n", atl[rep][locus].param_like);
       bufsize += strlen (input) + 1;
@@ -936,14 +991,13 @@ unpack_sumfile_buffer (char *buffer, world_fmt * world,
       sgets (input, LINESIZE, &buf);
       sscanf (input, "%li %li %li %lg", &ta[r][l].T, &ta[r][l].numpop,
               &ta[r][l].sumtips, &ta[r][locus].param_like);
-	world->chainlikes[l][r] = ta[r][l].param_like;
+      world->chainlikes[l][r] = ta[r][l].param_like;
 
       increase_timearchive (world, l, ta[r][l].T, world->numpop, r);
       for (i = 0; i < ta[r][l].T; i++)
         {
           sgets (input, LINESIZE, &buf);
-          sscanf (input, "%li ", &ta[r][l].tl[i].copies);
-          ta[r][l].tl[i].lcopies = ln_copies (ta[r][l].tl[i].copies);
+          sscanf (input, "%li %lg", &ta[r][l].tl[i].copies, &ta[r][l].tl[i].lcopies);
           for (j = 0; j < 3 * numpop + numpop * (numpop - 1); j++)
             {
               sgets (input, LINESIZE, &buf);
@@ -997,11 +1051,11 @@ pack_sumfile_buffer (char **buffer, world_fmt * world,
       memset(tempbuffer2,0,sizeof(char)*101*(22+ 3 * numpop + numpop * (numpop - 1) * 22 + 50 * numpop * numpop + 50));
       for (i = 0; i < ta[r][l].T; i++)
         {
-          //	  memset(tempbuffer,0,sizeof(char)*(22+ 3 * numpop + numpop * (numpop - 1) * 22 + 50 * numpop * numpop + 50));
+          //   memset(tempbuffer,0,sizeof(char)*(22+ 3 * numpop + numpop * (numpop - 1) * 22 + 50 * numpop * numpop + 50));
           tempbuffer[0]='\0';
-          sprintf (input, "%li\n", ta[r][l].tl[i].copies);
+          sprintf (input, "%li %g\n", ta[r][l].tl[i].copies, ta[r][l].tl[i].lcopies);
           strcat (tempbuffer, input);
-          //	  		  printf("%5li %5li\n",i,j);
+          //       printf("%5li %5li\n",i,j);
           for (j = 0; j < 3 * numpop + numpop * (numpop - 1); j++)
             {
               sprintf (input, "%g\n", ta[r][l].tl[i].data[j]);
@@ -1024,7 +1078,7 @@ pack_sumfile_buffer (char **buffer, world_fmt * world,
         }
       sprintf (input, "%li %g\n", ta[r][l].trials, ta[r][l].normd);
       strcat (tempbuffer, input);
-      //	  strcat(tempbuffer2,tempbuffer);
+      //   strcat(tempbuffer2,tempbuffer);
       strcat(*buffer,tempbuffer);
     }
   bufsize = strlen(*buffer);
@@ -1132,7 +1186,7 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
   long zz=0;
 #endif
 
-  allbuffer = (char *) calloc (bufsize, sizeof (char));	//some small value
+  allbuffer = (char *) calloc (bufsize, sizeof (char)); //some small value
   //buf = &buffer;
 #ifdef BIGMEMORY
 
@@ -1163,7 +1217,7 @@ mpi_results_worker (long bufs, world_fmt * world, long maxrep,
 
   for (ww = 0; ww < locidone; ww++)
     {
-      allbuffer = (char *) realloc (allbuffer, sizeof (char));	//some small value
+      allbuffer = (char *) realloc (allbuffer, sizeof (char)); //some small value
       //    buf = &allbuffer;
       locus = world->who[ww];
       bufsize = (*pack) (&allbuffer, world, locus, maxrep, numpop);
@@ -1183,7 +1237,7 @@ mpi_broadcast_results (world_fmt * world, long loci,
                                        long locus, long maxrep, long numpop))
 {
   long locus;
-  //	long addon = (world->loci == 1) 0 : 1;
+  // long addon = (world->loci == 1) 0 : 1;
   long bufsize=1;
   char nowstr[STRSIZE];
   char *allbuffer;// = &world->buffer;
@@ -1332,7 +1386,7 @@ mpi_profiles_master (world_fmt * world, long nparam, int *profilewho)
         }
       else
         {
-          MPI_Send (&nparam, 1, MPI_LONG, sender, 0, comm_world);	//end of parameter list
+          MPI_Send (&nparam, 1, MPI_LONG, sender, 0, comm_world); //end of parameter list
         }
     }
 }
@@ -1350,7 +1404,7 @@ mpi_profiles_worker (world_fmt * world, long *gmaxptr)
   while (!done)
     {
       MPI_Recv (&pnum, 1, MPI_LONG, MASTER, MPI_ANY_TAG, comm_world, &status);
-      if (status.MPI_TAG != 0)	//stop condition
+      if (status.MPI_TAG != 0) //stop condition
         {
           // fills world->buffer with profile information
           print_profile_likelihood_driver (pnum, world, gmaxptr);
@@ -1359,7 +1413,7 @@ mpi_profiles_worker (world_fmt * world, long *gmaxptr)
           if(world->options->printprofsummary)
             {
               temp[2] = pack_quantile (&quantilebuffer, world->quantiles[pnum], GRIDSIZE);
-              world->buffer =	    (char *) realloc (world->buffer,
+              world->buffer =     (char *) realloc (world->buffer,
                                                     sizeof (char) * (temp[1] + temp[2] + 1));
               strcat (world->buffer, quantilebuffer);
             }
@@ -1450,7 +1504,7 @@ assignloci_worker (world_fmt * world)
     {
       MPI_Recv (&locus, 1, MPI_LONG, MASTER, MPI_ANY_TAG,
                 comm_world, &status);
-      if (status.MPI_TAG != 0)	//stop condition
+      if (status.MPI_TAG != 0) //stop condition
         {
           swap_atl (locus, locidone, world);
 
@@ -1517,7 +1571,7 @@ setup_parameter0_slowmpi (world_fmt * world, nr_fmt * nr, long repkind,
                 }
             }
         }
-      else			//single locus
+      else   //single locus
         {
           if (repkind == SINGLECHAIN)
             {
@@ -1580,7 +1634,7 @@ setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
                 }
             }
         }
-      else			//single locus
+      else   //single locus
         {
           if (repkind == SINGLECHAIN)
             {
