@@ -4,13 +4,12 @@
 #include <mpi.h>
 #include "migration.h"
 extern MPI_Comm comm_world;
-extern MPI_Comm comm_all_worlds;
+//extern MPI_Comm comm_all_worlds;
 #endif
 extern int myID;
 extern int allID;
 extern int color;
 extern int numcpu;
-extern int numlocicpu;
 extern int locidone;
 extern int profiledone;
 
@@ -37,40 +36,40 @@ extern void broadcast_options (option_fmt * options);
 extern void mpi_runloci_master (long loci, int *who);
 
 extern void mpi_runloci_worker (world_fmt ** universe, int usize,
-				option_fmt * options, data_fmt * data,
-				tpool_t * heating_pool, long maxreplicate,
-				long *treefilepos, long *Gmax);
+                                  option_fmt * options, data_fmt * data,
+                                  tpool_t * heating_pool, long maxreplicate,
+                                  long *treefilepos, long *Gmax);
 
 extern double mpi_likelihood_master (double *param, double *lparam,
-				     world_fmt * world, nr_fmt * nr,
-				     helper_fmt * helper, int *who);
+                                       world_fmt * world, nr_fmt * nr,
+                                       helper_fmt * helper, int *who);
 extern void broadcast_options_master (option_fmt * options);
 extern void broadcast_options_worker (option_fmt * options);
 
 extern void broadcast_data_master (data_fmt * data, option_fmt * options);
 extern void broadcast_data_worker (data_fmt * data, option_fmt * options);
 extern void mpi_results_master (double sendtype, world_fmt * world,
-				long maxrep,
-				void (*unpack) (char *buffer,
-						world_fmt * world, long locus,
-						long maxrep, long numpop));
+                                  long maxrep,
+                                  void (*unpack) (char *buffer,
+                                                  world_fmt * world, long locus,
+                                                  long maxrep, long numpop));
 extern void mpi_results_worker (long bufsize, world_fmt * world, long maxrep,
-				long (*pack) (char **buffer,
-					      world_fmt * world, long locus,
-					      long maxrep, long numpop));
+                                  long (*pack) (char **buffer,
+                                                world_fmt * world, long locus,
+                                                long maxrep, long numpop));
 
 extern long pack_result_buffer (char **buffer, world_fmt * world,
-				long locus, long maxrep, long numpop);
+                                  long locus, long maxrep, long numpop);
 extern void unpack_result_buffer (char *buffer, world_fmt * world,
-				  long locus, long maxrep, long numpop);
+                                    long locus, long maxrep, long numpop);
 extern long pack_sumfile_buffer (char **buffer, world_fmt * world,
-				 long locus, long maxrep, long numpop);
+                                   long locus, long maxrep, long numpop);
 extern void unpack_sumfile_buffer (char *buffer, world_fmt * world,
-				   long locus, long maxrep, long numpop);
+                                     long locus, long maxrep, long numpop);
 extern long pack_mighist_buffer (char **buffer, world_fmt * world,
-				 long locus, long maxrep, long numpop);
+                                   long locus, long maxrep, long numpop);
 extern void unpack_mighist_buffer (char *buffer, world_fmt * world,
-				   long locus, long maxrep, long numpop);
+                                     long locus, long maxrep, long numpop);
 
 
 extern void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
@@ -84,15 +83,20 @@ extern void mpi_send_stop (world_fmt * world);
 extern void mpi_results_stop (void);
 extern void assignloci_worker (world_fmt * world);
 void setup_parameter0_mpi (world_fmt * world, nr_fmt * nr, long repkind,
-			   long repstart, long repstop, long loci, long kind,
-			   boolean multilocus);
+                           long repstart, long repstop, long loci, long kind,
+                           boolean multilocus);
 #ifdef SLOWNET
-void mpi_broadcast_results (world_fmt * world);
+void
+mpi_broadcast_results (world_fmt * world, long loci,
+                       long (*pack) (char **buffer, world_fmt * world,
+                                     long locus, long maxrep, long numpop),
+                       void (*unpack) (char *buffer, world_fmt * world,
+                                       long locus, long maxrep, long numpop));
 void mpi_profiles_master (world_fmt * world, long nparam, int *profilewho);
 void mpi_profiles_worker (world_fmt * world, long *gmaxptr);
 void setup_parameter0_slowmpi (world_fmt * world, nr_fmt * nr, long repkind,
-			       long repstart, long repstop, long loci,
-			       long kind, boolean multilocus);
+                               long repstart, long repstop, long loci,
+                               long kind, boolean multilocus);
 #endif /*slownet */
 #endif /*mpi */
 #endif
