@@ -10,6 +10,11 @@
  
 Copyright 2001 Peter Beerli and Joseph Felsenstein
  
+ This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+ 
 $Id: profile.c,v 1.55 2001/09/07 23:56:13 beerli Exp $
  
 -------------------------------------------------------*/
@@ -122,11 +127,13 @@ print_profile_likelihood_driver (long which, world_fmt * world, long *gmaxptr)
   static boolean onemig = FALSE;
   long i, j;
   //world->options->verbose = FALSE;
-
-  if (which == world->numpop2)	//gamma deviated mutation rate
+  world->locus = 0;
+  if (which == world->numpop2 && world->options->gamma) //gamma deviated mutation rate
     print_profile_likelihood (which, world, gmaxptr);
   else
     {
+      if(which>world->numpop2)
+        return 0;
       switch (world->options->custm2[which])
         {
         case 'C':
@@ -202,6 +209,11 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
   double likes[GRIDSIZE];
   long elem = world->options->gamma ? world->numpop * world->numpop + 1 :
               world->numpop * world->numpop;
+#ifdef LONGSUM
+
+  elem += world->numpop * 3;
+#endif /*LONGSUM*/
+
   nr = (nr_fmt *) calloc (1, sizeof (nr_fmt));
   create_nr (nr, world, *gmaxptr, which, world->loci,
              world->repkind, world->rep);
@@ -216,8 +228,8 @@ print_profile_likelihood (long which, world_fmt * world, long *gmaxptr)
       print_menu_profile (which,
                           world->numpop2 + (long) world->options->gamma);
     }
-    SETUPPARAM0 (world, nr, world->repkind, nr->repstart, nr->repstop,
-				 world->loci, PROFILE, world->loci>1 ?  TRUE : FALSE);
+  SETUPPARAM0 (world, nr, world->repkind, nr->repstart, nr->repstop,
+               world->loci, PROFILE, world->loci>1 ?  TRUE : FALSE);
   calc_profile_likelihood (method, which, likes, param, world, GRIDSIZE, nr);
   prepare_header (var, which, world);
   if (world->options->printprofile)
@@ -250,11 +262,16 @@ print_profile_table (char method, long which, char *var, double likes[],
     world->options->gamma ? world->numpop * world->numpop +
     1 : world->numpop * world->numpop;
 
-  char fp[LINESIZE * 10];	//large local string buffer
-  char **buffer = &world->buffer;	// buffer for printing whole table
+  char fp[LINESIZE * 10]; //large local string buffer
+  char **buffer = &world->buffer; // buffer for printing whole table
   long bufsize = 1;
   char *temp, *var2, temp2[LINESIZE], likestr[LINESIZE], *paramstr;
   double likemax = -DBL_MAX;
+#ifdef LONGSUM
+
+  elem += world->numpop * 3;
+#endif /*LONGSUM*/
+
   //memset (*buffer, 0, sizeof (char) * strlen (*buffer));
   (*buffer)[0] = '\0';
   var2 =
@@ -349,7 +366,7 @@ print_profile_table (char method, long which, char *var, double likes[],
         {
           if (((j + 1) % 5) == 0)
             {
-              sprintf (temp, "\n                              ");
+              sprintf (temp, "\n                               ");
               temp += 26;
             }
           if (param[i][j] <= 0)
@@ -441,7 +458,7 @@ warp (long ii)
 void
 print_profile_percentile (world_fmt * world)
 {
-  const double probabilities[] = SHOWGRID;	//debug GRID2
+  const double probabilities[] = SHOWGRID; //debug GRID2
   long i, j, jj;
   boolean first = TRUE;
   boolean last = FALSE;
@@ -477,7 +494,7 @@ print_profile_percentile (world_fmt * world)
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
-        continue;		/* this variable was not estimated, so return */
+        continue;  /* this variable was not estimated, so return */
       sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
       bufsize += strlen(fp);
       *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
@@ -512,7 +529,7 @@ print_profile_percentile (world_fmt * world)
   for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
     {
       if (world->quantiles[i].name[0] == '\0')
-        continue;		/* this variable was not estimated, so return */
+        continue;  /* this variable was not estimated, so return */
       sprintf (fp, "%-10.10s  ", world->quantiles[i].name);
       bufsize += strlen(fp);
       *buffer = (char *) realloc(*buffer, sizeof(char) * bufsize);
@@ -610,6 +627,12 @@ void
 prepare_header (char *var, long which, world_fmt * world)
 {
   long i, j, from, to;
+#ifdef LONGSUM
+
+  long len = world->numpop2 + world->options->gamma;
+  len += world->numpop * 3;
+#endif /*LONGSUM*/
+
   if (which < world->numpop)
     {
       sprintf (var, "Theta_%li", from = which + 1);
@@ -627,8 +650,14 @@ prepare_header (char *var, long which, world_fmt * world)
           else
             sprintf (var, "  M_%li%li", from, to);
         }
-      if (which == world->numpop2)
+      if (which == world->numpop2 && world->options->gamma)
         sprintf (var, " Alpha  ");
+#ifdef LONGSUM
+
+      if(which >= len && world->options->fluctuate)
+        sprintf(var," Rate_%li%li  ", (which - len) / world->numpop, ((which - len) % world->numpop)+1);
+#endif /*LONGSUM*/
+
     }
 }
 
@@ -641,11 +670,11 @@ calc_profile_likelihood (char method, long which, double *likes,
   switch (method)
     {
     case 'p' /*percentiles */ :
-    case 'q':			/*quick and dirty: no correlation between parametes */
-    case 'f':			/*mixture of quick and precise */
+    case 'q':   /*quick and dirty: no correlation between parametes */
+    case 'f':   /*mixture of quick and precise */
       profile_max_percentiles (which, likes, param, world, nn, nr);
       break;
-    case 's':			/* spline */
+    case 's':   /* spline */
     case 'd' /*discrete */ :
       profile_max_spline (method, which, likes, param, world, nr, nn);
       break;
@@ -709,6 +738,7 @@ profile_max_percentiles (long which, double *likes, double **param,
 
   long i, trials = 0;
   long df;
+  long len;
   boolean QD = FALSE, QD2 = FALSE;
   double prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
   double *mlparam;
@@ -748,13 +778,18 @@ profile_max_percentiles (long which, double *likes, double **param,
     }
   else
     {
-      mlparam = world->atl[rep][(world->locus=0)].param;
+      mlparam = world->atl[rep][world->locus].param;
       maxlike = world->atl[rep][world->locus].param_like;
     }
 
+  len = world->numpop2 +  (long) world->options->gamma;
+#ifdef LONGSUM
+
+  len += world->numpop * 3;
+#endif /*LONGSUM*/
+
+  memcpy (param[nn - 1], mlparam, sizeof (double) * len);
 
-  memcpy (param[nn - 1], mlparam,
-          sizeof (double) * (world->numpop2 + (long) world->options->gamma));
   likes[nn - 1] = maxlike;
   maxparam = param[nn - 1][which];
 
@@ -776,9 +811,14 @@ profile_max_percentiles (long which, double *likes, double **param,
       eventloop ();
 #endif
 
-      memcpy (param[i], mlparam,
-              sizeof (double) * (world->numpop2 +
-                                 (long) world->options->gamma));
+      len = world->numpop2 +  (long) world->options->gamma;
+#ifdef LONGSUM
+
+      len += world->numpop * 3;
+#endif /*LONGSUM*/
+
+      memcpy (param[i], mlparam, sizeof (double) * len);
+
       trials =
         find_profilelike (testlike, prob, i, minparam, maxparam, param[i],
                           &likes[i], which, world, QD, QD2, mlparam, &normd,
@@ -800,6 +840,7 @@ profile_max_spline (char method, long which, double *likes, double **param,
   const double probabilities[] = GRID;
   long i, trials = 0;
   long panic, df;
+  long len;
   double prob, normd, maxlike, testlike, minparam = 0, maxparam = 0;
   double *mlparam;
   double tmp, x, xx, xlow, xhigh, mid, low, high, value;
@@ -829,8 +870,13 @@ profile_max_spline (char method, long which, double *likes, double **param,
       mlparam = world->atl[rep][world->locus].param;
       maxlike = world->atl[rep][world->locus].param_like;
     }
-  memcpy (param[nn - 1], mlparam,
-          sizeof (double) * (world->numpop2 + (long) world->options->gamma));
+  len = world->numpop2 +  (long) world->options->gamma;
+#ifdef LONGSUM
+
+  len += world->numpop * 3;
+#endif /*LONGSUM*/
+
+  memcpy (param[nn - 1], mlparam, sizeof (double) * len);
   likes[nn - 1] = maxlike;
   maxparam = param[nn - 1][which];
   /* calculate likelihood at GRIDNODES */
@@ -840,8 +886,7 @@ profile_max_spline (char method, long which, double *likes, double **param,
         value = deviate[i];
       else
         value = deviate[i] * mlparam[which];
-      memcpy (param[i], mlparam,
-              sizeof (double) * (world->numpop2 + (long) world->options->gamma));
+      memcpy (param[i], mlparam, sizeof (double) * len);
       nr->profilenum = set_profile_param (param[i], which, nr->profiles,
                                           value, nr->values, world);
       //do_profiles(nr->world, nr, likes, &normd, PROFILE,
@@ -983,11 +1028,11 @@ calc_spline (double *param, double *like, long nn, long *constr, double *diff,
   /* call to spline.c routines */
   long degree = 3;
   long smoothness = 1;
-  long opt = 414;		//convex, monotone, derivatives constraints
-  double d0 = 0, dnp = 0, d20 = 0, d2np = 0;	//not used
+  long opt = 414;  //convex, monotone, derivatives constraints
+  double d0 = 0, dnp = 0, d20 = 0, d2np = 0; //not used
   double eps = 0.0001;
-  long kmax = 10;		//not used
-  long maxstp = 10;		//not used
+  long kmax = 10;  //not used
+  long maxstp = 10;  //not used
   long errc;
   dbvssc_ (param, like, &nn, &degree, &smoothness, &opt, &d0, &dnp, &d20,
            &d2np, constr, &eps, NULL, NULL, NULL, NULL, &kmax, &maxstp, &errc,
@@ -1100,7 +1145,7 @@ set_profile_param (double *param, long which, long *allwhich,
 {
   boolean has_fixed = FALSE;
 
-  long z = 0, i = 0, zz = 0, zzz = 0;	//zz is the counter for # fixed elements
+  long z = 0, i = 0, zz = 0, zzz = 0; //zz is the counter for # fixed elements
   long numpop = world->numpop;
   long numpop2 = world->numpop2;
   char *p;
@@ -1290,7 +1335,13 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
   long loc = world->loci > 1 ? world->loci : 0;
   helper_fmt helper;
   double *ltestparam;
-  ltestparam = (double *) calloc (nr->numpop2 + 1, sizeof (double));
+  long len = world->numpop2 +  (long) world->options->gamma;
+#ifdef LONGSUM
+
+  len += world->numpop * 3;
+#endif /*LONGSUM*/
+
+  ltestparam = (double *) calloc (len, sizeof (double));
   *normd = -1;
   prepare_broyden (PROFILE, world, &helper.multilocus);
   if (probabilities[whichprob] < 0.5)
@@ -1315,19 +1366,20 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
           xhigh = maxparam;
         }
     }
+
+
   // QD=TRUE -> calculate only CALCLIKE for parameter
   // QD2=TRUE -> assumes QD and then adds a maximizer step
   // if both are false maximize all parameters
   if (QD)
     {
-      memcpy (testparam, mlparam, sizeof (double) *
-              (world->numpop2 + (long) world->options->gamma));
+      memcpy (testparam, mlparam, sizeof (double) * len);
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
                                           xlow, nr->values, world);
       testparam[which] = xlow;
       set_logparam (ltestparam, testparam, nr->partsize);
       //SETUPPARAM0 (world, nr, world->repkind, nr->repstart, nr->repstop,
-      //	world->loci, PROFILE, helper.multilocus);
+      // world->loci, PROFILE, helper.multilocus);
       if(world->options->gamma)
         initgammacat (nr->categs, testparam[nr->numpop2],1./* EXP (lparam[0])*/,
                       nr->rate, nr->probcat);
@@ -1348,18 +1400,18 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
     }
   else
     {
-      memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+      memcpy (testparam, mlparam, sizeof (double) * len);
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
                                           xlow, nr->values, world);
       maximize (testparam, world, nr, PROFILE, world->repkind);
       low = nr->llike;
-      memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+      memcpy (testparam, mlparam, sizeof (double) *len);
       nr->profilenum = set_profile_param (testparam, which, nr->profiles,
                                           xhigh, nr->values, world);
       maximize (testparam, world, nr, PROFILE, world->repkind);
       high = nr->llike;
 
-      //	testlike = high - 0.5 * find_chi (1, prob);
+      // testlike = high - 0.5 * find_chi (1, prob);
 
       if (fabs(high - world->atl[rep][loc].param_like)>EPSILON*10)
         printf
@@ -1373,14 +1425,13 @@ find_profilelike (double testlike, double prob, long whichprob, double minparam,
     {
       if (QD)
         {
-          memcpy (testparam, mlparam, sizeof (double) * nr->partsize);
+          memcpy (testparam, mlparam, sizeof (double) * len);
           nr->profilenum = set_profile_param (testparam, which,
                                               nr->profiles, x,
                                               nr->values, world);
           testparam[which] = x;
-          initgammacat (nr->categs, testparam[nr->numpop2],1./* EXP (lparam[0])*/,
-                        nr->rate, nr->probcat);
-
+          if(nr->world->options->gamma)
+            initgammacat (nr->categs, testparam[nr->numpop2],1.,nr->rate, nr->probcat);
           set_logparam (ltestparam, testparam, nr->partsize);
           fill_helper (&helper, testparam, ltestparam, world, nr);
           mid = CALCLIKE (&helper, testparam, ltestparam);
@@ -1469,9 +1520,15 @@ void
 allocate_profile_percentiles (world_fmt * world)
 {
   long i;
+  long len = world->numpop2 + (world->options->gamma ? 1 : 0);
+#ifdef LONGSUM
+
+  len += world->numpop*3;
+#endif /*LONGSUM*/
+
   world->quantiles =
-    (quantile_fmt *) calloc (1, sizeof (quantile_fmt) * (world->numpop2 + 1));
-  for (i = 0; i < world->numpop2 + 1; i++)
+    (quantile_fmt *) calloc (1, sizeof (quantile_fmt) *len);
+  for (i = 0; i < len; i++)
     {
       world->quantiles[i].name = (char *) calloc (1, sizeof (char) * 20);
       world->quantiles[i].param =
@@ -1483,7 +1540,13 @@ void
 destroy_profile_percentiles (world_fmt * world)
 {
   long i;
-  for (i = 0; i < world->numpop2 + (long) world->options->gamma; i++)
+  long len = world->numpop2 + (world->options->gamma ? 1 : 0);
+#ifdef LONGSUM
+
+  len += world->numpop*3;
+#endif /*LONGSUM*/
+
+  for (i = 0; i < len; i++)
     {
       free (world->quantiles[i].name);
       free (world->quantiles[i].param);
@@ -1584,8 +1647,8 @@ void calc_grid(FILE *alldim, world_fmt * world,  double *testparam, double *ltes
   //double maxlike;
   helper_fmt helper;
   double saveparam, lsaveparam;
-  //	for(j=0; j<nr->numpop2; j++)
-  //	  {
+  // for(j=0; j<nr->numpop2; j++)
+  //   {
   if(which<world->numpop2)
     {
       saveparam = testparam[which];
@@ -1601,7 +1664,7 @@ void calc_grid(FILE *alldim, world_fmt * world,  double *testparam, double *ltes
               fill_helper (&helper, testparam, ltestparam, world, nr);
               //fprintf(alldim,"%li %li ",which,i);
               //for(z=0;z<world->numpop2;z++)
-              //	  fprintf(alldim, "%g ", testparam[z]);
+              //   fprintf(alldim, "%g ", testparam[z]);
               fprintf(alldim, "%f ", CALCLIKE (&helper, testparam, ltestparam));
             }
           calc_grid(alldim, world,testparam,ltestparam, mlparam, nr,which+1);
@@ -1611,7 +1674,7 @@ void calc_grid(FILE *alldim, world_fmt * world,  double *testparam, double *ltes
       testparam[which] = saveparam;
       ltestparam[which] =lsaveparam;
     }
-  //	  }
+  //   }
   //      fprintf(world->mathfile, "\n");
 }
 #endif
