@@ -5,12 +5,16 @@
  -------------------------------------------------------                        
  S E Q U E N C E S   R O U T I N E S 
  
- used in menu.c
  
  Peter Beerli 1996, Seattle
  beerli@genetics.washington.edu
  
- Copyright 2001 Peter Beerli and Joseph Felsenstein
+ Copyright 2002 Peter Beerli and Joseph Felsenstein
+ 
+  This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
  
  $Id: sequence.c,v 1.38 2001/09/07 23:56:13 beerli Exp $
  
@@ -192,7 +196,7 @@ initfreqs (double *freqa, double *freqc, double *freqg, double *freqt)
 
 void
 initcatn (long *categs)
-{				/* initialize category number */
+{    /* initialize category number */
 
   do
     {
@@ -206,7 +210,7 @@ initcatn (long *categs)
 
 boolean
 initcategs (long categs, double *rate, double *probcat)
-{				/* initialize rate categories */
+{    /* initialize rate categories */
   long i;
   char input[LINESIZE];
   char rest[LINESIZE];
@@ -391,7 +395,7 @@ makeweights (world_fmt * world, data_fmt * data, long locus)
 {
   /* make up weights vector to avoid duplicate computations */
   long i;
-  //  world->data->seq->endsite = 1;
+  world->data->seq->endsite = 1;
   for (i = 0; i < world->data->seq->sites[locus]; i++)
     {
       world->data->seq->alias[i] = i + 1;
@@ -414,7 +418,7 @@ makeweights (world_fmt * world, data_fmt * data, long locus)
         world->data->seq->alias[i - 1];
     }
   init_sequences2 (world, world->data->seq, locus);
-}				/* makeweights */
+}    /* makeweights */
 
 void
 init_sequences2 (world_fmt * world, seqmodel_fmt * seq, long locus)
@@ -445,11 +449,13 @@ makevalues_seq (world_fmt * world, option_fmt * options, data_fmt * data,
       i = -1;
       for (pop = 0; pop < world->numpop; pop++)
         {
-          for (ii = 0; ii < data->numind[pop][locus]; ii++)
+          for (ii = 0; ii < data->numalleles[pop][locus]; ii++)
             {
               i++;
-              if (!options->usertree)
-                strcpy (treenode[i]->nayme, data->indnames[pop][ii]);
+              if (k==0 && !options->usertree)
+					{
+						strcpy (treenode[i]->nayme, data->indnames[pop][ii]);
+					}
               for (l = 0; l < world->options->rcategs; l++)
                 {
                   for (b = 0; b < 4; b++)
@@ -581,11 +587,13 @@ makevalues_snp (world_fmt * world, option_fmt * options, data_fmt * data,
       i = -1;
       for (pop = 0; pop < world->numpop; pop++)
         {
-          for (ii = 0; ii < data->numind[pop][locus]; ii++)
+          for (ii = 0; ii < data->numalleles[pop][locus]; ii++)
             {
               i++;
-              if (!options->usertree)
-                strcpy (treenode[i]->nayme, data->indnames[pop][ii]);
+              if (k==0 && !options->usertree)
+				{
+					strcpy (treenode[i]->nayme, data->indnames[pop][ii]);
+				}
               for (l = 0; l < world->options->rcategs; l++)
                 {
                   if (pop == 0)
@@ -829,7 +837,7 @@ make_invarsites (world_fmt * world, data_fmt * data, long locus)
   i = -1;
   for (pop = 0; pop < world->numpop; pop++)
     {
-      for (ii = 0; ii < data->numind[pop][locus]; ii++)
+      for (ii = 0; ii < data->numalleles[pop][locus]; ii++)
         {
           i++;
           z = 0;
@@ -855,7 +863,7 @@ make_invarsites_unlinked (world_fmt * world, data_fmt * data, long locus)
   i = -1;
   for (pop = 0; pop < world->numpop; pop++)
     {
-      for (ii = 0; ii < data->numind[pop][locus]; ii++)
+      for (ii = 0; ii < data->numalleles[pop][locus]; ii++)
         {
           i++;
           z = 0;
@@ -877,7 +885,7 @@ make_invarsites_unlinked (world_fmt * world, data_fmt * data, long locus)
                 {
                   for (l = 0; l < world->options->rcategs; l++)
                     {
-                      treenode[i]->x.s[k][l][0] = 1.0;	//putting ? for data
+                      treenode[i]->x.s[k][l][0] = 1.0; //putting ? for data
                       treenode[i]->x.s[k][l][1] = 1.0;
                       treenode[i]->x.s[k][l][2] = 1.0;
                       treenode[i]->x.s[k][l][3] = 1.0;
@@ -899,13 +907,13 @@ sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus)
   temppop = (long *) calloc (1, sizeof (long) * world->numpop);
   for (i = 0; i < world->numpop; i++)
     {
-      if (data->numind[i][FLOC] > 0)
+      if (data->numind[i][locus] > 0)
         {
           temppop[z] = i;
           if (z == 0)
-            tempsum[z] = data->numind[i][FLOC];
+            tempsum[z] = data->numind[i][locus];
           else
-            tempsum[z] = tempsum[z - 1] + data->numind[i][FLOC];
+            tempsum[z] = tempsum[z - 1] + data->numind[i][locus];
           z++;
         }
     }
@@ -966,7 +974,7 @@ sitesort2 (world_fmt * world, data_fmt * data, long sites, long locus)
     }
   free (tempsum);
   free (temppop);
-}				/* sitesort2 */
+}    /* sitesort2 */
 
 
 void
@@ -978,16 +986,16 @@ sitecombine2 (world_fmt * world, data_fmt * data, long sites, long locus)
   long *tempsum, *temppop;
   tempsum = (long *) calloc (1, sizeof (long) * world->numpop);
   temppop = (long *) calloc (1, sizeof (long) * world->numpop);
-  tempsum[0] = data->numind[0][FLOC];
+  tempsum[0] = data->numind[0][locus];
   for (i = 0; i < world->numpop; i++)
     {
-      if (data->numind[i][FLOC] > 0)
+      if (data->numind[i][locus] > 0)
         {
           temppop[z] = i;
           if (z == 0)
-            tempsum[z] = data->numind[i][FLOC];
+            tempsum[z] = data->numind[i][locus];
           else
-            tempsum[z] = tempsum[z - 1] + data->numind[i][FLOC];
+            tempsum[z] = tempsum[z - 1] + data->numind[i][locus];
           z++;
         }
     }
@@ -1040,7 +1048,7 @@ sitecombine2 (world_fmt * world, data_fmt * data, long sites, long locus)
     }
   free (temppop);
   free (tempsum);
-}				/* sitecombine2 */
+}    /* sitecombine2 */
 
 
 void
@@ -1089,7 +1097,7 @@ sitescrunch2 (world_fmt * world, long sites, long i, long j, long locus)
         }
       done = (done || i >= sites);
     }
-}				/* sitescrunch2 */
+}    /* sitescrunch2 */
 
 void
 inputoptions (world_fmt * world, option_fmt * options, data_fmt * data,
@@ -1110,7 +1118,7 @@ inputoptions (world_fmt * world, option_fmt * options, data_fmt * data,
     {
       inputcategs (0, sites, world, options, data);
     }
-}				/* inputoptions */
+}    /* inputoptions */
 
 void
 inputweights (world_fmt * world, data_fmt * data, long chars)
@@ -1142,7 +1150,7 @@ inputweights (world_fmt * world, data_fmt * data, long chars)
           exit (EXIT_FAILURE);
         }
     }
-}				/* inputweights */
+}    /* inputweights */
 
 void
 inputcategs (long a, long b, world_fmt * world, option_fmt * options,
@@ -1186,7 +1194,7 @@ inputcategs (long a, long b, world_fmt * world, option_fmt * options,
           exit (EXIT_FAILURE);
         }
     }
-}				/* inputcategs */
+}    /* inputcategs */
 
 
 
@@ -1234,7 +1242,7 @@ empiricalfreqs (world_fmt * world, option_fmt * options, seqmodel_fmt * seq,
       options->freqg = sumg / summ;
       options->freqt = sumt / summ;
     }
-}				/* empiricalfreqs */
+}    /* empiricalfreqs */
 
 
 void
@@ -1296,7 +1304,7 @@ init_tbl (world_fmt * world, long locus)
         world->tbl[i][j]->ratxi /= sumrates;
         world->tbl[i][j]->ratxv /= sumrates;
       }
-}				/* inittable */
+}    /* inittable */
 
 void
 print_weights (FILE * outfile, world_fmt * world, option_fmt * options,
@@ -1369,7 +1377,7 @@ printweights (FILE * outfile, world_fmt * world, option_fmt * options,
         putc (' ', outfile);
     }
   fprintf (outfile, "\n\n");
-}				/* printweights */
+}    /* printweights */
 
 
 
@@ -1484,7 +1492,7 @@ treelike_seq (world_fmt * world, long locus)
       summ += log (sum2);
     }
   return summ;
-}				/* treelikelihood */
+}    /* treelikelihood */
 
 void
 snp_invariants (contribarr invariants, long endsite, long rcategs,
@@ -1532,7 +1540,7 @@ treelike_snp (world_fmt * world, long locus)
           x1 = &(p->x.s[i][j]);
           tterm[j] =
             (seq->freqa * (*x1)[0] + seq->freqc * (*x1)[1] +
-             seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]) / invariants[j];
+             seq->freqg * (*x1)[2] + seq->freqt * (*x1)[3]) /invariants[j];
         }
       sumterm = 0.0;
       for (j = 0; j < opt->rcategs; j++)
@@ -1542,7 +1550,7 @@ treelike_snp (world_fmt * world, long locus)
         world->contribution[i][j] = tterm[j] / sumterm;
 
       summ += seq->aliasweight[i] * lterm;
-    }				/* over endsite - 4[snp-invariants] */
+    }    /* over endsite - 4[snp-invariants] */
   for (j = 0; j < opt->rcategs; j++)
     like[j] = 1.0;
   for (i = 0; i < seq->sites[locus]; i++)
@@ -1572,7 +1580,7 @@ treelike_snp (world_fmt * world, long locus)
     sum2 += opt->probcat[i] * like[i];
   summ += log (sum2);
   return summ;
-}				/* treelike_snp */
+}    /* treelike_snp */
 
 
 double
@@ -1615,7 +1623,7 @@ treelike_snp_unlinked (world_fmt * world, long locus)
           datasum + log ((1 - EXP (log (summ) - datasum)) / invariants[0]);
     }
   return result;
-}				/* treelike_snp_unlinked */
+}    /* treelike_snp_unlinked */
 
 void
 check_basefreq (option_fmt * options)
