@@ -15,9 +15,14 @@
    anyway, but tries to say why in a way which is      
    for humans better understandable  (I hope)                       
    -----------------------------------------------------     
-   part of the lamarc package                   
+   part of the migrate                   
  
-   P. Beerli                            
+   Copyright 1996-2002 Peter Beerli
+    This software is distributed free of charge for non-commercial use
+ and is copyrighted. Of course, we do not guarantee that the software
+ works and are not responsible for any damage you may cause or have.
+ 
+   $Id$                  
    ----------------------------------------------------- */
 //#include <stdio.h>
 #ifndef __MWERKS__
