@@ -1,6 +1,6 @@
 #ifndef SIGNAL_HANDLER
 #define SIGNAL_HANDLER
-/* -----------------------------------------------------  
+/* -----------------------------------------------------
    sighandler.h                                           
    handels to following signals:                          
    SIGIOT         Input/Output problems                   
@@ -15,7 +15,7 @@
    for humans better understandable                       
    -----------------------------------------------------  
    part of the lamarc package                             
-
+ 
    P. Beerli                                              
    ----------------------------------------------------- */
 #ifdef NEXTAPP
@@ -38,14 +38,21 @@ extern void malloc_error_found (int value);
 #endif
 #ifdef LAMARC_MALLOC
 extern void *LAMARC_malloc (const unsigned long size, const char file[],
-			    const long line);
+                              const long line);
 extern void *LAMARC_calloc (const unsigned long repeats,
-			    const unsigned long size, const char file[],
-			    const long line);
+                              const unsigned long size, const char file[],
+                              const long line);
 extern void *LAMARC_realloc (void *ptr, const unsigned long size,
-			     const char file[], const long line);
+                               const char file[], const long line);
 #define malloc(a) LAMARC_malloc((unsigned long) a,__FILE__,__LINE__)
 #define calloc(b,a) LAMARC_calloc((unsigned long) b, a,__FILE__,__LINE__)
 #define realloc(c,a) LAMARC_realloc(c, (unsigned long) a,__FILE__,__LINE__)
 #endif
+
+#ifdef DEBUG_MPI
+#define MPI_Send(a,b,c,d,e,f) printf("%i>before send (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Send(a,b,c,d,e,f);printf("%i>after send (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
+#define MPI_Recv(a,b,c,d,e,f,g) printf("%i>before receive (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Recv(a,b,c,d,e,f,g);printf("%i>after receive (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
+#define MPI_Bcast(a,b,c,d,e) printf("%i>before broadcast (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Bcast(a,b,c,d,e);printf("%i>after broadcast (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
+#define MPI_Barrier(a) printf("%i>before barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout);MPI_Barrier(a);printf("%i>after barrier (%s,%i)\n",myID, __FILE__,__LINE__);fflush(stdout)
+#endif
 #endif
