@@ -1,14 +1,29 @@
-// unique event polymorphism UEP
-//
-//
+/*------------------------------------------------------
+ Maximum likelihood estimation
+ of migration rate  and effectice population size
+ using a Metropolis-Hastings Monte Carlo algorithm
+ -------------------------------------------------------
+ Unique event polymorphism   R O U T I N E S
+ 
+ Peter Beerli 2000, Seattle
+ beerli@genetics.washington.edu
+ 
+Copyright 2002 Peter Beerli and Joseph Felsenstein
+ 
+         This software is distributed free of charge for non-commercial use
+        and is copyrighted. Of course, we do not guarantee that the software
+        works and are not responsible for any damage you may cause or have.
+ 
+$Id$
+*/
 #ifdef UEP
 #include "migration.h"
 #include "tools.h"
 #include "random.h"
 #include "uep.h"
 
-#define AVERAGE    0		/* used for time of uep */
-#define POPULATION 1		/* used for time of uep given that it raised in */
+#define AVERAGE    0  /* used for time of uep */
+#define POPULATION 1  /* used for time of uep given that it raised in */
 /*   pop x */
 
 node *first_uep (node * p, node * nop, long uepsites);
@@ -231,7 +246,7 @@ allocate_uep (node * p, world_fmt * world, char datatype, boolean withtips)
     {
       if (withtips)
         {
-          //	  p->ux.s = (pair *) calloc (world->data->uepsites, sizeof (pair));
+          //   p->ux.s = (pair *) calloc (world->data->uepsites, sizeof (pair));
         }
     }
 }
@@ -352,10 +367,10 @@ treelike_uep (world_fmt * world, long locus)
       //        scale = p->uepscale[i];
       tterm =
         world->options->uepfreq0 * (*x1)[0] + world->options->uepfreq1 * (*x1)[1];
-      summ += (log (tterm));	//+ scale);
+      summ += (log (tterm)); //+ scale);
     }
   return summ;
-}				/* treelikelihood */
+}    /* treelikelihood */
 
 
 // uses the conditional likelihoods to set
@@ -520,7 +535,7 @@ print_uep (FILE * out, world_fmt * world, long copies)
   fprintf (out, "-------------------------------------------------\n");
   fprintf (out, "Populations  Probability   Time(*)       Time(**)\n");
   fprintf (out, "-------------------------------------------------\n");
-  prob = calc_uep_popprob (world, copies, -1);	// don't care if anc uep=1/0
+  prob = calc_uep_popprob (world, copies, -1); // don't care if anc uep=1/0
   tyme = calc_uep_timeprob (world, copies, AVERAGE, -1);
   timep = calc_uep_timeprob (world, copies, POPULATION, -1);
   for (pop = 0; pop < world->numpop; ++pop)
@@ -536,7 +551,7 @@ print_uep (FILE * out, world_fmt * world, long copies)
   fprintf (out, "-------------------------------------------------\n");
   fprintf (out, "Populations  Probability   Time(*)       Time(**)\n");
   fprintf (out, "-------------------------------------------------\n");
-  prob = calc_uep_popprob (world, copies, 1);	// don't care if anc uep=1
+  prob = calc_uep_popprob (world, copies, 1); // don't care if anc uep=1
   tyme = calc_uep_timeprob (world, copies, AVERAGE, 1);
   timep = calc_uep_timeprob (world, copies, POPULATION, 1);
   for (pop = 0; pop < world->numpop; ++pop)
@@ -552,7 +567,7 @@ print_uep (FILE * out, world_fmt * world, long copies)
   fprintf (out, "-------------------------------------------------\n");
   fprintf (out, "Populations  Probability   Time(*)       Time(**)\n");
   fprintf (out, "-------------------------------------------------\n");
-  prob = calc_uep_popprob (world, copies, 0);	// don't care if anc uep=0
+  prob = calc_uep_popprob (world, copies, 0); // don't care if anc uep=0
   tyme = calc_uep_timeprob (world, copies, AVERAGE, 0);
   timep = calc_uep_timeprob (world, copies, POPULATION, 0);
   for (pop = 0; pop < world->numpop; ++pop)
@@ -822,7 +837,7 @@ calc_ueplike (node * p, world_fmt * world, double **ueplike)
               temp = (d1->uep[i]=='0'  ? 0 : 1 )+ (d2->uep[i]=='0' ? 0 : 1);
               if (temp == 1)
                 {
-                  if (!done)	//shortcut as long we have only one UEP
+                  if (!done) //shortcut as long we have only one UEP
                     {
                       printf ("CALCUEP: at <%li> with time %f (%f,%f)\n",p->id,p->tyme,d1->tyme,d2->tyme);
                       collect_ueplike (p, d1, d2, i, world, ueplike[i]);
@@ -1086,7 +1101,7 @@ adjust_uep_oback (node * first, node * firstb, proposal_fmt * proposal,
   double lasttime = 0.;
   node *last, *p;
   //double expT = EXP (-(proposal->treelen-proposal->world->treelen));
-  if (first->tyme < proposal->time)	// target == osister
+  if (first->tyme < proposal->time) // target == osister
     first = proposal->oback;
   for (u = 0; u < proposal->world->data->uepsites; ++u)
     {
@@ -1241,7 +1256,7 @@ adjust_uep_osistertarget2 (node * first, node * firstb,
 double
 pseudo_ueplikelihood (world_fmt * world, proposal_fmt * proposal)
 {
-  double interval = 0., oldinterval = 0.;	//  node *first, *firstb;
+  double interval = 0., oldinterval = 0.; //  node *first, *firstb;
   node *root = proposal->root->next->back;
   long uepsites = proposal->world->data->uepsites;
 
@@ -1359,7 +1374,7 @@ pseudo_ueplikelihood (world_fmt * world, proposal_fmt * proposal)
             }
         }
     }
-  return -DBL_MAX;		//never come here
+  return -DBL_MAX;  //never come here
 }
 
 double
