@@ -54,7 +54,7 @@ extern void print_simresults (world_fmt * world);
 extern void print_list (world_fmt ** universe, option_fmt * options,
                           data_fmt * data);
 extern void cleanup_world (world_fmt * world, long locus);
-extern void apocalypse_now (world_fmt * world);
+extern void free_universe (world_fmt ** worlds, long numworlds);
 extern void test_locus_like (nr_fmt * nr, double *param0, double *param1,
                                long df, long locus, world_fmt * world,
                                long *maxwhich, long maxnum, boolean withhead,
